<?php
/**
 * Plugin Name: AffiliateBooster Blocks
 * Plugin URI: https://www.affiliatebooster.com/
 * Description: #1 affiliate plugin to increase your sales.
 * Version: 2.1.10
 * Author: 20script
 * Author URI: https://www.20script.ir/
 * License: GPL2
 * License URI: http://www.gnu.org/licenses/gpl-2.0.txt
 *
 * Text Domain: affiliatebooster-blocks
 */

/**
 * Exit if accessed directly
 */
if (!defined('ABSPATH')) {
    exit;
}

define('AFB_DOMAIN', 'affiliate-booster');
define('AFB_DIR', plugin_dir_path(__FILE__));
define('AFB_URL', plugins_url('/', __FILE__));


$ab_amazon_api_key = get_option( 'ab_amazon_api_key' ) ? get_option( 'ab_amazon_api_key' ) : '';
$ab_amazon_api_secret  = get_option( 'ab_amazon_api_secret' ) ? get_option( 'ab_amazon_api_secret' ) : '';
$ab_amazon_country  = get_option( 'ab_amazon_country' ) ? get_option( 'ab_amazon_country' ) : '';
$ab_amazon_api_tracking_id  = get_option( 'ab_amazon_api_tracking_id' ) ? get_option( 'ab_amazon_api_tracking_id' ) : '';

define('AB_AMAZON_KEY',$ab_amazon_api_key);
define('AB_AMAZON_SECRET_KEY',$ab_amazon_api_secret);
define('AB_AMAZON_COUNTRY',$ab_amazon_country);
define('AB_AMAZON_TAG_ID',$ab_amazon_api_tracking_id);

/**
 * Initialize the blocks
 */ 
function affiliate_booster_gutenberg_loader() {
    /**
     * Load the blocks functionality
     */
    require_once ( AFB_DIR . 'dist/init.php');
    require_once ( AFB_DIR . 'updater/license.php');
    //require_once ( AFB_DIR . 'libraries/amazon-paapi5/ab-amazon-api.php');
    require_once ( AFB_DIR . 'disableblocks/class-abdisable-gutenberg-blocks.php');

    include_once ABSPATH . 'wp-admin/includes/plugin.php';

    if ( is_plugin_active( 'gutenberg/gutenberg.php' ) || version_compare( get_bloginfo( 'version' ), '4.9.9', '>' ) ) {
        ABDisable_Gutenberg_Blocks::instance();
    }

}

add_action('plugins_loaded', 'affiliate_booster_gutenberg_loader');

/**
 * Load the plugin text-domain
 */
function affiliate_booster_gutenberg_init() {
    load_plugin_textdomain('affiliate-booster', false, basename(dirname(__FILE__)) . '/languages');
}

add_action('init', 'affiliate_booster_gutenberg_init');

/**
 * Load the plugin welcome page css
 */
function affiliate_booster_load_admin_scripts( $hook ) {
    wp_register_style( 'affiliatebooster-welcome', AFB_URL.'/assets/css/affiliatebooster-welcome.css', false, '' );
    wp_enqueue_style( 'affiliatebooster-welcome' );
}
add_action( 'admin_enqueue_scripts', 'affiliate_booster_load_admin_scripts' );


/**
 * Add a check for our plugin before redirecting
 */
function affiliate_booster_gutenberg_activate() {
    add_option('affiliate_booster_gutenberg_do_activation_redirect', true);
}

register_activation_hook(__FILE__, 'affiliate_booster_gutenberg_activate');

/**
 * Redirect to the affiliate booster page on single plugin activation
 */
function affiliate_booster_gutenberg_redirect() {
    if ( get_option( 'affiliate_booster_gutenberg_do_activation_redirect', false ) ) {
        delete_option( 'affiliate_booster_gutenberg_do_activation_redirect' );
        if( !isset( $_GET['activate-multi'] ) ) {
            wp_redirect( "admin.php?page=affiliate_booster" ); 
        }
    }
}
add_action( 'admin_init', 'affiliate_booster_gutenberg_redirect' );

/**
 * Adds a menu item for the affiliatebooster-blocks page.
 *
 * since 1.0.0
 */
function affiliate_booster_getting_started_menu() {

    add_menu_page(
        __( 'Affiliate Booster', 'affiliatebooster-blocks' ),
        __( 'Affiliate Booster', 'affiliatebooster-blocks' ),
        'manage_options',
        'affiliate_booster',
        'affiliate_booster_welcome_page',
        AFB_URL.'/assets/images/icon.png'
    );

}
add_action( 'admin_menu', 'affiliate_booster_getting_started_menu' );


/**
 * Outputs the markup used on the affiliatebooster-blocks
 *
 * since 1.0.0
 */
function affiliate_booster_welcome_page() {
    require_once plugin_dir_path( __FILE__ ) . 'src/welcome_page.php';
}


/**
 * Create Affiliate Booster Categories
 */
add_filter( 'block_categories_all', function( $categories, $post ) {

    $status  = get_option( 'affbooster_license_status' );
    if($status == 'valid'){
    	return array_merge(
    		$categories,
    		array(
    			array(
    				'slug' => 'affiliate-booster',
    				'title' => __( 'Affiliate Booster', 'affiliate-booster' ),
    			),
    		)
    	);
    }else{
        return array_merge(
            $categories,
            array(
                array(
                    
                ),
            )
        );
    }

}, 10, 2 );



/**
 * Filter code to remove noopener rel from external links.
 */
add_filter( 'rank_math/noopener', '__return_false');

/**
 * TOC Adding In Rank Math Plugin
 */
add_filter( 'rank_math/researches/toc_plugins', function( $toc_plugins ) {
       $toc_plugins['affiliatebooster-blocks/affiliatebooster-blocks.php'] = 'AffiliateBooster Blocks';
    return $toc_plugins;
});



/**
 * Add plugin action links.
 *
 * Add a link to the settings page on the plugins.php page.
 *
 * @since 1.0.0
 *
 * @param  array  $links List of existing plugin action links.
 * @return array         List of modified plugin action links.
 */
function ab_plugin_action_links( $links ) {

    $links = array_merge($links, array(
        '<a href="' . esc_url( admin_url( '/?page=affiliate_booster' ) ) . '">' . __( 'Settings', 'affiliatebooster-blocks' ) . '</a>',        
    ) );

    $links = array_merge($links, array(
        '<a target="_blank" href="' . esc_url( 'https://help.affiliatebooster.com/' ) . '">' . __( 'Tutorials', 'affiliatebooster-blocks' ) . '</a>',        
    ) );

    $links = array_merge($links, array(
        '<a target="_blank" href="' . esc_url( 'https://store.affiliatebooster.com/support/' ) . '">' . __( 'Support', 'affiliatebooster-blocks' ) . '</a>',        
    ) );
    return $links;

}
add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'ab_plugin_action_links' );


function licence_update_hook() {
    if(isset($_REQUEST['sl_activation']) && $_REQUEST['sl_activation'] == 'success'){    
        update_option( 'affbooster_plugin_license_key', $_REQUEST['key'] );
        update_option( 'affbooster_license_status', $_REQUEST['st'] );
        echo 'success';exit;
    }
}
add_action('wp_head', 'licence_update_hook');

add_shortcode( 'AB_AMAZON_IMAGE', 'ab_amazon_product_image_fn' );
function ab_amazon_product_image_fn( $atts ) {  
    /*if(isset($atts['asin']) && $atts['asin'] != ''){
        $amazon = new AB_AMAZON_API();
        $response = $amazon->get_product($atts['asin'],array('box'));                
        if(isset($response) && !empty($response)){
            $ImageURL = $response->data['Images']['Primary']['Large']['URL'];
            return $ImageURL;
        }else{
            return __('Please Check Amazon API Connection Or ASIN Code',AFB_DOMAIN);
        }
    }else{
        return __('Please Enter ASIN Code',AFB_DOMAIN);
    }*/
}

add_shortcode( 'AB_AMAZON_PRICE', 'ab_amazon_product_price_fn' );
function ab_amazon_product_price_fn( $atts ) {  
    /*if(isset($atts['asin']) && $atts['asin'] != ''){
        $amazon = new AB_AMAZON_API();
        $response = $amazon->get_product($atts['asin'],array('box'));        
        if(isset($response) && !empty($response)){ 
            $Price = $response->data['Offers']['Listings']['0']['Price']['DisplayAmount'];
            return 'Price: '.$Price;
        }else{
            return __('Please Check Amazon API Connection Or ASIN Code',AFB_DOMAIN);
        }
    }else{
        return __('Please Enter ASIN Code',AFB_DOMAIN);
    }*/
}

add_shortcode( 'AB_AMAZON_RATING', 'ab_amazon_product_rating_fn' );
function ab_amazon_product_rating_fn( $atts ) {  
    /*if(isset($atts['asin']) && $atts['asin'] != ''){
        $amazon = new AB_AMAZON_API();
        $response = $amazon->get_product($atts['asin'],array('box'));        
        if(isset($response) && !empty($response)){ 
            $FeedbackRating = $response->data['Offers']['Listings']['0']['MerchantInfo']['FeedbackRating'];
            return 'Rating: '.$FeedbackRating;
        }else{
            return __('Please Check Amazon API Connection Or ASIN Code',AFB_DOMAIN);
        }
    }else{
        return __('Please Enter ASIN Code',AFB_DOMAIN);
    }*/
}
 
// remove wp version number from scripts and styles
function remove_css_js_version( $src ) {
    if( strpos( $src, '?ver=' ) )
        $src = remove_query_arg( 'ver', $src );
    return $src;
}
add_filter( 'style_loader_src', 'remove_css_js_version', 9999 );
add_filter( 'script_loader_src', 'remove_css_js_version', 9999 );