import attributes from './attributes';
import Edit from './Edit.js';
import icons from '../../icons/icons'; 
import classnames from "classnames"
import { EmptyStar, FullStar, HalfStar } from "./icons";
const { Component, Fragment } = wp.element;
const { 	
	InspectorControls,    
	AlignmentToolbar,
	BlockControls,
	PanelColorSettings,
	MediaUpload,
	RichText,
	URLInput,
	InnerBlocks,
	__experimentalLinkControl
} = wp.blockEditor;
const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const NEW_TAB_REL = 'noopener noreferrer';

registerBlockType( 'affiliate-booster/ab-key-points', {
	title: __( 'AB - Key Points' ), 
	icon: icons.star, 
	category: 'affiliate-booster',
	keywords: [
		__( 'Star Review' ),
	],
	supports: {
        html: false,
        // className: false,
    },
	attributes,
	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.	
	 */
	edit: Edit,	

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.	
	 */
	save: function( props ) {
		const { InnerBlocks } = wp.blockEditor
		var {highlightedStars, attributes: { 
			idtbl,
			
			block_id,
		    boxShadow,
		    boxBgColor,

		    boxBorderType,
            boxBorderColor,
            boxBorderWidth,

		    // Title settings
		    titleInsideOutside,
		    titleLoadGoogleFonts,
		    titleBgColor,
		    titleTextColor,
		    titlefontFamily,
		    titlefontWeight,
		    titlefontSubset,
		    titlefontSizeType,
		    titlefontSizeTypeMobile,
		    titlefontSizeTypeTablet,
		    titlefontSizeDesktop,
		    titlefontSizeMobile,
		    titlefontSizeTablet,
		    titlelineHeight,
		    titlelineHeightMobile,
		    titlelineHeightTablet,
		    titleletterSpacing,
		    titleletterSpacingMobile,
		    titleletterSpacingTablet,
		    titleletterSpacingType,
		    titleletterSpacingTypeTablet,
		    titleletterSpacingTypeMobile,
		    titletextTransform,
		    titletextDecoration,
		    titlefontStyle,
		    titleTag,
		    titleText,
		    titleShow,
		    subTitleTag,
		    
		    // Key Points 
		    keypoints,

		    // Key Points Label
		    kpLabelText,
		    kpLabelLoadGoogleFonts,
		    kpLabelColor,
		    kpLabelfontFamily,
		    kpLabelfontWeight,
		    kpLabelfontSubset,
		    kpLabelfontSizeType,
		    kpLabelfontSizeTypeMobile,
		    kpLabelfontSizeTypeTablet,
		    kpLabelfontSizeDesktop,
		    kpLabelfontSizeMobile,
		    kpLabelfontSizeTablet,
		    kpLabellineHeight,
		    kpLabellineHeightMobile,
		    kpLabellineHeightTablet,
		    kpLabelletterSpacing,
		    kpLabelletterSpacingMobile,
		    kpLabelletterSpacingTablet,
		    kpLabelletterSpacingType,
		    kpLabelletterSpacingTypeTablet,
		    kpLabelletterSpacingTypeMobile,
		    kpLabeltextTransform,
		    kpLabeltextDecoration,
		    kpLabelfontStyle,     
		    kpLabelAlignment,
		    kpLabelAlignmentMobile,
		    kpLabelAlignmentTablet,    
		    
		    // Key Points Content
		    kpContentText, 
		    kpContentLoadGoogleFonts,
		    kpContentColor,
		    kpContentfontFamily,
		    kpContentfontWeight,
		    kpContentfontSubset,
		    kpContentfontSizeType,
		    kpContentfontSizeTypeMobile,
		    kpContentfontSizeTypeTablet,
		    kpContentfontSizeDesktop,
		    kpContentfontSizeMobile,
		    kpContentfontSizeTablet,
		    kpContentlineHeight,
		    kpContentlineHeightMobile,
		    kpContentlineHeightTablet,
		    kpContentletterSpacing,
		    kpContentletterSpacingMobile,
		    kpContentletterSpacingTablet,
		    kpContentletterSpacingType,
		    kpContentletterSpacingTypeTablet,
		    kpContentletterSpacingTypeMobile,
		    kpContenttextTransform,
		    kpContenttextDecoration,
		    kpContentfontStyle, 
		    kpContentAlignment,
		    kpContentAlignmentMobile,
		    kpContentAlignmentTablet,

		    //Star rating
		    starRatingShow,
			starRatingCount,
		    starRatingColor,
		    starRatingSelectedStars,
		    starRatingSize,
		    starRatingSizeMobile,
		    starRatingSizeTablet,

		    //Btn 
		    btnShow,
		    btnText,
            btnHref,
            btnRel,
            btnLoadGoogleFonts,
            btnfontFamily,
            btnfontWeight,
            btnfontSubset,
            btnfontSizeType,
            btnfontSizeTypeMobile,
            btnfontSizeTypeTablet,
            btnfontSizeDesktop,
            btnfontSizeMobile,
            btnfontSizeTablet,
            btnlineHeight,
            btnlineHeightMobile,
            btnlineHeightTablet,
            btnletterSpacing,
            btnletterSpacingMobile,
            btnletterSpacingTablet,
            btnletterSpacingType,
            btnletterSpacingTypeTablet,
            btnletterSpacingTypeMobile,
            btntextTransform,
            btntextDecoration,
            btnfontStyle,
            btnBgColor,
            btnHoverBgColor,
            btnTextColor,
            btnTextHoverColor,
            btnBorderColor,
            btnBorderHoverColor,
            btn_Htarget,            
            btnPadding,
            btnPaddingMobile,
            btnPaddingTablet,
            btnMargin,
            btnMarginMobile,
            btnMarginTablet,
            btnAlignment,
            btnAlignmentMobile,
            btnAlignmentTablet,
            btnBorder,
            btnBorderType,
            btnBorderMobile,
            btnBorderTablet,
            btnBorderRadius,
            btnBorderRadiusMobile,
            btnBorderRadiusTablet,
            btnIconPosition,
            bntRounded,
            btnSize,
            btnWidth,
            btnIcon,


            //Extra Content
            showExtraContent,
            extraContentText,
            extraContentLoadGoogleFonts, 
		    extraContentTextColor,
		    extraContentfontFamily,
		    extraContentfontWeight,
		    extraContentfontSubset,
		    extraContentfontSizeType,
		    extraContentfontSizeTypeMobile,
		    extraContentfontSizeTypeTablet,
		    extraContentfontSizeDesktop,
		    extraContentfontSizeMobile,
		    extraContentfontSizeTablet,
		    extraContentlineHeight,
		    extraContentlineHeightMobile,
		    extraContentlineHeightTablet,
		    extraContentletterSpacing,
		    extraContentletterSpacingMobile,
		    extraContentletterSpacingTablet,
		    extraContentletterSpacingType,
		    extraContentletterSpacingTypeTablet,
		    extraContentletterSpacingTypeMobile,
		    extraContenttextTransform,
		    extraContenttextDecoration,
		    extraContentfontStyle,

		    enableGlimmerEffect,

		    enableSchema,
            schemaType,
            schemaSubType,
            schemaTitle,
            schemaDescription,
            schemaRating, 
            schemaApplicationCategory,
            schemaOperatingSystem,
            schemaOffer,
            schemaOfferPrice, 
            schemaOfferPriceCurrency, 
            schemaBrand,
		    schemaSku,
		    schemaIdentifierType,
		    schemaIdentifier,
		    schemaImage,
		    schemaAuthor,

		} } = props;	

		const Tag = titleTag
		const SubTag = subTitleTag

		let slugName = titleText.toString().toLowerCase().replace(/( |<.+?>|&nbsp;)/g, "-");  		 

		let newrel;
        if( !btn_Htarget){
            newrel = btnRel
        } else  if( !btn_Htarget && btnRel === NEW_TAB_REL){
            newrel = btnRel
        } else if ( btn_Htarget && !btnRel ) {
          newrel = NEW_TAB_REL
        } else {
          newrel = NEW_TAB_REL + ' ' + btnRel
        }

        function removeDuplicateWords (s) {
            var str = s.split(" ");
            var result = [];
            for(var i =0; i < str.length ; i++){
                if(result.indexOf(str[i]) === -1){
                  result.push(str[i]);
                } 
            }
            return result.join(" ");
        }
            
        newrel = removeDuplicateWords(newrel).trim()

		const repetdata = props.attributes.keypoints.map( ( location, index )  => {
			
			let label = location.label;
			let content = location.content;
					
			return  <li  key={ index }>								
						<div className={`affiliate-keypoints-row`} >
							
							<Fragment>
								<div className={`affiliate-keypoints-label`}> 
									<RichText.Content 
										tagName={SubTag}
										className={`label`} 
										value = { label }
									/>
								</div>
							</Fragment>

							<Fragment>
								<div className={`affiliate-keypoints-content`}> 
									<RichText.Content 
										className={`content`}
										value = { content }
									/>
								</div>
							</Fragment>

						</div> 
					</li>;				
			});

		return (
				<div id={`affiliate-style-${block_id}`} className={ props.className }>

					{ enableSchema && enableSchema == true && schemaType && schemaType == 'Product' &&	
						<Fragment>
						<asside style="visibility: hidden;height: 0px !important;display: inherit;" itemprop="Review" itemscope itemtype="https://schema.org/Review">
							<span itemprop="reviewBody">{schemaTitle}</span>
							<span itemprop="description">{schemaDescription}</span>

							<span itemprop="itemReviewed" itemscope itemtype={`https://schema.org/${schemaSubType}`}>
								<span itemprop="name">{schemaTitle}</span>
								<span itemprop="description">{schemaDescription}</span>	
								<span itemprop="image">{schemaImage.url}</span>		
								<span itemprop="sku">{schemaSku}</span>		
								<span itemprop="brand" itemscope itemtype="https://schema.org/Brand">	
									<span itemprop="name">{schemaBrand}</span>	
								</span>	
								<span itemprop="offers" itemscope itemtype="https://schema.org/Offer">
									<span itemprop="status">{schemaOffer}</span>
									<span itemprop="price">{schemaOfferPrice}</span> 
									<span itemprop="currency">{schemaOfferPriceCurrency}</span>
								</span>
								{ schemaIdentifierType && schemaIdentifierType == 'gtin' &&	
									<span itemprop="gtin">{schemaIdentifier}</span>
								}
								{ schemaIdentifierType && schemaIdentifierType == 'mpn' &&	
									<span itemprop="mpn">{schemaIdentifier}</span>
								}
								{ schemaIdentifierType && schemaIdentifierType == 'isbn' &&	
									<span itemprop="isbn">{schemaIdentifier}</span>
								}
							</span>
							<span itemprop="author" itemscope itemtype="https://schema.org/Person">
								<span itemprop="name">{schemaAuthor}</span>
							</span>
						</asside>
						</Fragment>
					}

					{ enableSchema && enableSchema == true && schemaType && schemaType == 'Course' &&

						<Fragment>
						<asside style="visibility: hidden;height: 0px !important;display: inherit;" itemprop="Review" itemscope itemtype="https://schema.org/Review">
							<span itemprop="reviewBody">{schemaTitle}</span>
							<span itemprop="description">{schemaDescription}</span>
							<span itemprop="itemReviewed" itemscope itemtype="https://schema.org/Course">
								<span itemprop="name">{schemaTitle}</span>
								<span itemprop="description">{schemaDescription}</span>	
								<span itemprop="provider">{schemaAuthor}</span>
							</span>
							<span itemprop="reviewRating" itemscope itemtype={`https://schema.org/Rating`}> 
								<span itemprop="ratingValue">{schemaRating}</span>	
								<span itemprop="bestRating">5</span>
							</span>
							<span itemprop="author" itemscope itemtype="https://schema.org/Person">
								<span itemprop="name">{schemaAuthor}</span>
							</span>
						</asside>
						</Fragment>
					}

					{ enableSchema && enableSchema == true && schemaType && schemaType == 'SoftwareApplication' &&	

						<Fragment>
						<asside style="visibility: hidden;height: 0px !important;display: inherit;" itemprop="Review" itemscope itemtype="https://schema.org/Review">
							<span itemprop="reviewBody">{schemaTitle}</span>
							<span itemprop="description">{schemaDescription}</span>
							<span itemprop="itemReviewed" itemscope itemtype={`https://schema.org/${schemaSubType}`}>
								<span itemprop="name">{schemaTitle}</span> 
								<span itemprop="applicationCategory">{schemaApplicationCategory}</span>
								<span itemprop="operatingSystem">{schemaOperatingSystem}</span> 
								<span itemprop="offers" itemscope itemtype="https://schema.org/Offer">
									<span itemprop="status">{schemaOffer}</span>
									<span itemprop="price">{schemaOfferPrice}</span> 
									<span itemprop="currency">{schemaOfferPriceCurrency}</span>
								</span>								
							</span>
							<span itemprop="reviewRating" itemscope itemtype={`https://schema.org/Rating`}> 
								<span itemprop="ratingValue">{schemaRating}</span>	
								<span itemprop="bestRating">5</span>
							</span>
							<span itemprop="author" itemscope itemtype="https://schema.org/Person">
								<span itemprop="name">{schemaAuthor}</span>
							</span>
						</asside>
						</Fragment>
					}

					<div className={`affiliate-keypoints-box`}>

						<div className={`affiliate-keypoints-inner`}>

							{ titleShow && titleShow == true &&	titleInsideOutside && titleInsideOutside == true &&	
								<RichText.Content 
		                            tagName={Tag}
		                            value={titleText}
		                            className="affiliate-keypoints-titleText  inside"
		                            id={slugName}
		                        />
		                    }

		                    { titleShow && titleShow == true &&	!titleInsideOutside && !titleInsideOutside == true &&
								<RichText.Content 
		                            tagName={Tag}
		                            value={titleText}
		                            className="affiliate-keypoints-titleText  outside"
		                            id={slugName}
		                        />
		                    }

							<ul className={`affiliate-keypoints-contentrows`}>
								{repetdata}				
							</ul>
 
							<div className={`affiliate-keypoints-footerbox`}>

								{ starRatingShow && starRatingShow == true &&	
									<div className={`affiliate-keypoints-col left`}>

										<div className={`affiliate-keypoints-starratingtext`}>
											<Fragment>OVERALL RATING</Fragment>	
										</div>										
										<div className="affiliate-keypoints-starrating" onMouseLeave={() => this.setState({ highlightedStars: 0 })} >
	                                        {[...Array(starRatingCount)].map((e, i) => (
	                                          <div className={`affiliate-star-item`} key={i}>
	                                                {i < (highlightedStars ? highlightedStars : starRatingSelectedStars) ? (
	                                                    highlightedStars ? (
	                                                        highlightedStars - 1 === i ? (
	                                                            starRatingSelectedStars % 1 > 0 ? (
	                                                                highlightedStars - starRatingSelectedStars - 0.5 !== 0 ? (
	                                                                    <HalfStar fillColor={starRatingColor} />
	                                                                ) : (
	                                                                    <FullStar fillColor={starRatingColor} />
	                                                                )
	                                                            ) : highlightedStars - starRatingSelectedStars !== 0 ? (
	                                                                <FullStar fillColor={starRatingColor} />
	                                                            ) : (
	                                                                <HalfStar fillColor={starRatingColor} />
	                                                            )
	                                                        ) : (
	                                                            <FullStar fillColor={starRatingColor} />
	                                                        )
	                                                    ) : starRatingSelectedStars - i >= 1 ? (
	                                                        <FullStar fillColor={starRatingColor} />
	                                                    ) : (
	                                                        <HalfStar fillColor={starRatingColor} />
	                                                    )
	                                                ) : (
	                                                    <EmptyStar fillColor={starRatingColor} />
	                                                )}
	                                            </div>
	                                        ))}
	                                    </div>

				                    </div>
				                }

				                { btnShow && btnShow == true &&
			                      	<div className={`affiliate-keypoints-col right`}>
			                      		
			                      		<div className={`affiliate-keypoints-btn`}>
	                                            <div className={`affiliate-keypoints-btn-wrapper`}>
	                                                <a href = {btnHref} className={classnames(`affiliate-btn  btn-is-${btnSize} ${btnWidth === "full"? "btn-is-fullw": btnWidth === "flex"? `btn-is-flex-${btnSize}`: ""} ${bntRounded ? 'btn-is-rounded' : ''} ${enableGlimmerEffect ? 'glimmer-effect' : ''}`).trim()}  
	                                                    {...(btn_Htarget ? {...btn_Htarget && { rel: newrel }} : { rel: newrel }  )}
	                                                    {...(btn_Htarget ? { target: '_blank' } : '' )}
	                                                    >
	                                                    { btnIconPosition && btnIconPosition == 'af-icon-is-left' &&
	                                                        <i className={`affiliate-abbtn-icon ${btnIcon} ${btnIconPosition}`}></i>
	                                                    }
	                                                    { btnIconPosition && btnIconPosition != 'af-icon-is-left' &&
	                                                        <i className={`affiliate-abbtn-icon af-icon-is-left`}></i>
	                                                    }
	                                                    <RichText.Content value={btnText} />
	                                                    { btnIconPosition && btnIconPosition == 'af-icon-is-right' &&
	                                                        <i className={`affiliate-abbtn-icon ${btnIcon} ${btnIconPosition}`}></i>
	                                                    }
	                                                    { btnIconPosition && btnIconPosition != 'af-icon-is-right' &&
	                                                        <i className={`affiliate-abbtn-icon af-icon-is-right`}></i>
	                                                    }
	                                                </a>
	                                            </div>
	                                        </div> 

			                      	</div>
			                    }


			                    { showExtraContent && showExtraContent == true &&	
									<div className={`affiliate-keypoints-footercol`}>

										<RichText.Content  
				                            value={extraContentText}
				                            className="affiliate-keypoints-extraContentText" 
				                        />	

				                    </div>
				                }

							</div>

						</div>

					</div>

				</div>
			);
		},
} );
