import attributes from './attributes';
import Edit from './Edit.js';
import icons from '../../icons/icons';
const { Component, Fragment } = wp.element;
const { 	
	InspectorControls,    
	AlignmentToolbar,
	BlockControls,
	PanelColorSettings,
	MediaUpload,
	RichText,
	URLInput,
	InnerBlocks,
	__experimentalLinkControl
} = wp.blockEditor;
const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const NEW_TAB_REL = 'noopener noreferrer';

registerBlockType( 'affiliate-booster/ab-product-table-1', {
	title: __( 'AB - Product Table 1' ), 
	icon: icons.comparison, 
	category: 'affiliate-booster',
	keywords: [
		__( 'NicheTable' ),
		__( 'Comparison Table' ),
		__( 'Best Responsive Comparison Table for Gutenberg Editor' ),
	],
	supports: {
        html: false,
        // className: false,
    },
	attributes,
	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.	
	 */
	edit: Edit,	

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.	
	 */
	save: function( props ) {
		const { InnerBlocks } = wp.blockEditor
		var { attributes: { block_id,idtbl,designType, tdbox, th0_txt, th1_txt, th2_txt, th3_txt, th4_txt, 
			HTxtColor, HBgColor, tEvenColor,btnRel,titleTag1, tOddColor,btnWidth, btn_Htarget,showItemRating,buttonIcon,iconPosition,
			badgeText,titleText, inside_circle,
			btn_Style,link, tdTxtColor, th_fontsize, td_fontsize, showReadMore,


			showColumn1,
		    showColumn2,
		    showColumn3,
		    showColumn4,
		    showColumn5,

		    enableGlimmerEffect,

		} } = props;	
		const Tag1 = titleTag1
		const trDisplay = props.attributes.tdbox.map( ( location, index )  => {
			let newrel;
			if( !location.btn_Htarget){
				newrel = location.btnRel
			} else  if( !location.btn_Htarget && location.btnRel === NEW_TAB_REL){
				newrel = location.btnRel
			} else if ( location.btn_Htarget && !location.btnRel ) {
			newrel = NEW_TAB_REL
			} else {
			newrel = NEW_TAB_REL + ' ' + location.btnRel
			}
			function removeDuplicateWords (s) {
				var str = s.split(" ");
				var result = [];
				for(var i =0; i < str.length ; i++){
					if(result.indexOf(str[i]) === -1){
					  result.push(str[i]);
					} 
				}
				 return result.join(" ");
				}
				
			newrel = removeDuplicateWords(newrel).trim()
			let slugName = location.fdprd.toString().toLowerCase().replace(/( |<.+?>|&nbsp;)/g, "-");
			
			return <tr  key={ index }>		
			{ showColumn1 && showColumn1 == true &&	
				<td data-column={th0_txt} className="affiliate-col-rank">
					#{ index+1 }
				</td>		
			}
			{ showColumn2 && showColumn2 == true &&	
				<td data-column={th1_txt} className="affiliate-col-img">
					{ designType && designType == 'ab-dynamic-design' &&
						<InnerBlocks.Content/>
					}
					{ designType && designType == 'ab-fixed-design' &&
						<img src={ location.mediaURL } className="affiliate-img" />
					}				
				</td>
			}
			{ showColumn3 && showColumn3 == true &&	
			<td data-column={th2_txt} className={`affiliate-col-ct1`} >
				
				<Fragment>
					<Tag1>
						<RichText.Content
							tagName= {'span'}
							className={`affiliate-txtbox-title`}
							value = { location.fdprd }
							id={slugName}
						/>
						
					</Tag1>
					<RichText.Content
						tagName="ul"
						multiline="li"
						value = {location.fddetail}
					/>
				</Fragment>
			
				
			</td>
			}
			{ showColumn4 && showColumn4 == true &&	
			<td data-column={th3_txt} className={`affiliate-col-ct2`}>

				<div className={`affiliate-rating-circle`}>
					<div class="progress" data-percentage={ location.itemRating }>
						<span class="progress-left">
							<span class="progress-bar"></span>
						</span>
						<span class="progress-right">
							<span class="progress-bar"></span>
				    	</span>
				    	{ inside_circle && inside_circle == true && 
				    		<RichText.Content
								tagName= {'span'}
								className = "affiliate-img-rating inside"
								placeholder = "0"
								value = { location.itemRating }
							/>
				    	}
					</div>
				</div>

				{ !inside_circle && !inside_circle == true &&
					<RichText.Content
						tagName= {'span'}
						className = "affiliate-img-rating outside"
						placeholder = "0"
						value = { location.itemRating }
					/>
				}
				
			</td>
			}
			{ showColumn5 && showColumn5 == true &&	
				<td className={`affiliate-col-btn`} data-column={th4_txt}> 

					{ location.mediaURL1 && location.mediaURL1 != '' &&
						<img src={ location.mediaURL1 } alt={ location.fdprd } className="affiliate-img affiliateimg1" />
					}

					<Fragment>
						<a className={`affiliate-producttable1-btn ${btnWidth}  ${enableGlimmerEffect ? 'glimmer-effect' : ''} ` + btn_Style }  href={location.fdbtnurl} title={location.fdbtntitle} 
							// rel={location.btnRel } 
							{...(location.btn_Htarget ? {...location.btn_Htarget && { rel: newrel }} : { rel: newrel }  )}
							{...(location.btn_Htarget ? { target: '_blank' } : '' )}>

							{ iconPosition && iconPosition == 'af-icon-is-left' && buttonIcon !== '' &&
								<i className={`${buttonIcon} affiliate-abbtn-icon ${iconPosition}`}></i>
							}
							<RichText.Content
								tagName={'span'}
								value = { location.fdbtn }
							/>
							{ iconPosition && iconPosition == 'af-icon-is-right' && buttonIcon !== '' &&
								<i className={`${buttonIcon} affiliate-abbtn-icon ${iconPosition}`}></i>
							}
						</a>
						
					</Fragment>
				</td>
			}
			</tr>;				
		});
		return (
				<div id={`affiliate-style-${block_id}`} className={ props.className }>
				<table className={`affiliate-producttable1-inner`}>
				<thead className={`affiliate-producttable1-th`}>
				<tr>
					{ showColumn1 && showColumn1 == true &&
						<th>{th0_txt}</th>
					}
					{ showColumn2 && showColumn2 == true &&
						<th>{th1_txt}</th>
					}
					{ showColumn3 && showColumn3 == true &&
						<th>{th2_txt}</th>
					}
					{ showColumn4 && showColumn4 == true &&
						<th>{th3_txt}</th> 
					}
					{ showColumn5 && showColumn5 == true &&
						<th>{th4_txt}</th>						
					}
				</tr>
				</thead>
				<tbody className={`affiliate-producttable1-cntn`}>
					{trDisplay}				
				</tbody>
				</table>
				</div>
		);
	},
} );
