import attributes from './attributes';
import Edit from './Edit.js';
import icons from '../../icons/icons';
const { Component, Fragment } = wp.element;
const { 	
	InspectorControls,    
	AlignmentToolbar,
	BlockControls,
	PanelColorSettings,
	MediaUpload,
	RichText,
	URLInput,
	InnerBlocks,
	__experimentalLinkControl
} = wp.blockEditor;
const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const NEW_TAB_REL = 'noopener noreferrer';

registerBlockType( 'affiliate-booster/ab-product-table-2', {
	title: __( 'AB - Product Table 2' ), 
	icon: icons.comparison, 
	category: 'affiliate-booster',
	keywords: [
		__( 'NicheTable' ),
		__( 'Comparison Table' ),
		__( 'Best Responsive Comparison Table for Gutenberg Editor' ),
	],
	supports: {
        html: false,
        // className: false,
    },
	attributes,
	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.	
	 */
	edit: Edit,	

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.	
	 */
	save: function( props ) {
		const { InnerBlocks } = wp.blockEditor
		var { attributes: { block_id,idtbl,designType, tdbox, th0_txt, th1_txt, th2_txt, th3_txt, th4_txt, 
			HTxtColor, HBgColor, tEvenColor,btnRel,titleTag1, tOddColor,btnWidth, btn_Htarget,showItemRating,buttonIcon,iconPosition,
			badgeText,titleText, 
			btn_Style,link, tdTxtColor, th_fontsize, td_fontsize, showReadMore,

			showColumn1,
		    showColumn2,
		    showColumn3,
		    showColumn4,

		    enableGlimmerEffect,

		    showBadge,

		} } = props;	
		const Tag1 = titleTag1
		const trDisplay = props.attributes.tdbox.map( ( location, index )  => {
			let newrel;
			if( !location.btn_Htarget){
				newrel = location.btnRel
			} else  if( !location.btn_Htarget && location.btnRel === NEW_TAB_REL){
				newrel = location.btnRel
			} else if ( location.btn_Htarget && !location.btnRel ) {
			newrel = NEW_TAB_REL
			} else {
			newrel = NEW_TAB_REL + ' ' + location.btnRel
			}
			function removeDuplicateWords (s) {
				var str = s.split(" ");
				var result = [];
				for(var i =0; i < str.length ; i++){
					if(result.indexOf(str[i]) === -1){
					  result.push(str[i]);
					} 
				}
				 return result.join(" ");
				}
				
			newrel = removeDuplicateWords(newrel).trim()
			let slugName = location.fdprd.toString().toLowerCase().replace(/( |<.+?>|&nbsp;)/g, "-");
			
			return <tr  key={ index }>			

			{ showColumn1 && showColumn1 == true &&
				<td data-column={th0_txt} className="affiliate-col-img">
					<div className="affiliate-col-rank">	
						{ index+1 }
					</div>

					<RichText.Content
						tagName= {'span'}
						className = "affiliate-item-badge mb"
						value = { location.badgeText }
					/>

					{ designType && designType == 'ab-dynamic-design' &&
						<InnerBlocks.Content/>
					}
					{ designType && designType == 'ab-fixed-design' && location.mediaURL && location.mediaURL != '' &&
						
						<img src={ location.mediaURL } alt={ location.fdprd } className="affiliate-img" />
					}	

				</td>		
			}

			{ showColumn2 && showColumn2 == true &&
				<td data-column={th1_txt} className="affiliate-col-ct1">
					
					{ showBadge && showBadge == true &&
						<RichText.Content
							tagName= {'span'}
							className = "affiliate-item-badge dtp"
							value = { location.badgeText }
						/>
					}
					
					<Fragment>
						<Tag1>
							<RichText.Content
								tagName= {'span'}
								className={`affiliate-txtbox-title`}
								value = { location.fdprd }
								id={slugName}
							/>
							
						</Tag1>
						<RichText.Content
							tagName="ul"
							multiline="li"
							value = {location.fddetail}
						/>
					</Fragment>	
				</td>
			}

			{ showColumn3 && showColumn3 == true &&
				<td data-column={th2_txt} className={`affiliate-col-ct1`} >

					<RichText.Content
						tagName= {'span'}
						className = "affiliate-img-rating"
						placeholder = "0"
						value = { location.itemRating }
					/>
					
					<div  className={`affiliate-rating-circle`}> 
					    <div class="progress2">
					        <div class="progress-bar2" role="progressbar" aria-valuenow={ location.itemRating } aria-valuemin="0" aria-valuemax="100">
					        
					        </div>
					    </div>
					</div>
					
					
					<Fragment>
						{showReadMore == true &&
								<RichText.Content
									tagName={'span'}
									value = {location.readMoreText}
									// href = {location.link}
									className={`affiliate-producttable2-readmore`}
								/>
							}
						</Fragment>
					
				</td>
			}
			
			{ showColumn4 && showColumn4 == true &&			
				<td className={`affiliate-col-btn`} data-column={th3_txt}> 				

					{ location.mediaURL1 && location.mediaURL1 != '' &&
						<img src={ location.mediaURL1 } alt={ location.fdprd } className="affiliate-img affiliateimg2" />
					}

					<Fragment>
						<a className={`affiliate-producttable2-btn ${btnWidth}  ${enableGlimmerEffect ? 'glimmer-effect' : ''} ` + btn_Style }  href={location.fdbtnurl} title={location.fdbtntitle} 
							// rel={location.btnRel } 
							{...(location.btn_Htarget ? {...location.btn_Htarget && { rel: newrel }} : { rel: newrel }  )}
							{...(location.btn_Htarget ? { target: '_blank' } : '' )}>

							{ iconPosition && iconPosition == 'af-icon-is-left' && buttonIcon !== '' &&
								<i className={`${buttonIcon} affiliate-abbtn-icon ${iconPosition}`}></i>
							}
							<RichText.Content
								tagName={'span'}
								value = { location.fdbtn }
							/>
							{ iconPosition && iconPosition == 'af-icon-is-right' && buttonIcon !== '' &&
								<i className={`${buttonIcon} affiliate-abbtn-icon ${iconPosition}`}></i>
							}
						</a>
						
					</Fragment>
				</td>
			}
			</tr>;				
		});
		return (
				<div id={`affiliate-style-${block_id}`} className={ props.className }>
				<table className={`affiliate-producttable2-inner`}>
				<thead className={`affiliate-producttable2-th`}>
				<tr>
					{ showColumn1 && showColumn1 == true &&
						<th>{th0_txt}</th>
					}
					{ showColumn2 && showColumn2 == true &&
						<th>{th1_txt}</th>
					}
					{ showColumn3 && showColumn3 == true &&
						<th>{th2_txt}</th>
					}
					{ showColumn4 && showColumn4 == true &&
						<th>{th3_txt}</th>
					}
				</tr>
				</thead>
				<tbody className={`affiliate-producttable2-cntn`}>
					{trDisplay}				
				</tbody>
				</table>
				</div>
		);
	},
} );
