import attributes from './attributes';
import Edit from './Edit.js';
import icons from '../../icons/icons';
import { EmptyStar, FullStar, HalfStar } from "./icons";
import classnames from "classnames"
const { Component, Fragment } = wp.element;
const { 	
	InspectorControls,    
	AlignmentToolbar,
	BlockControls,
	PanelColorSettings,
	MediaUpload,
	RichText,
	URLInput,
	InnerBlocks,
	__experimentalLinkControl
} = wp.blockEditor;
const { __ } = wp.i18n;
const { registerBlockType } = wp.blocks;
const NEW_TAB_REL = 'noopener noreferrer';

registerBlockType( 'affiliate-booster/ab-star-review', {
	title: __( 'AB Conclusion' ), 
	icon: icons.star, 
	category: 'affiliate-booster',
	keywords: [
		__( 'Star Review' ),
	],
	supports: {
        html: false,
        // className: false,
    },
	attributes,
	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.	
	 */
	edit: Edit,	

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.	
	 */
	save: function( props ) {
		const { InnerBlocks } = wp.blockEditor
		var { attributes: { 
			block_id,
			idtbl,
			mainTitle, 
			subTitle,
			reviewbox, 
			boxBgColor, 
			titleTag1, 	
			titleTag2, 			
			titleText, 			
			starsSize, 
			starsSizeMobile, 
			starsSizeTablet, 
			ratings, 
			ratingsColor, 

			starReviewContent,


			showTitle,
		    showRating,
		    showConclusionTitle,
		    showConclusionSummary,


		    //Button
		    btnShow,
		    btnBgColor,
			btnSize,
			btnRel,
			btnWidth,
			btnIcon,
			btnTitle,
			btnBgHoverColor, 
			btnTarget,
			bntRounded, 
			btnHref, 
			btnIconPosition,
			btnAlignment,
			btnAlignmentMobile,
			btnAlignmentTablet,
			btnPadding,
			btnPaddingTablet,
			btnPaddingMobile,
			btnMargin,
			btnMarginTablet,
			btnMarginMobile,
			btnLoadGoogleFonts,
			btnfontFamily,
			btnfontWeight,
			btnfontSubset,
			btnfontSizeType,
			btnfontSizeTypeMobile,
			btnfontSizeTypeTablet,
			btnfontSizeDesktop,
			btnfontSizeMobile,
			btnfontSizeTablet,
			btnlineHeight,
			btnlineHeightMobile,
			btnlineHeightTablet,
			btnletterSpacing,
			btnletterSpacingMobile,
			btnletterSpacingTablet,
			btnletterSpacingType,
			btnletterSpacingTypeTablet,
			btnletterSpacingTypeMobile,
			btntextTransform,
			btntextDecoration,
			btnfontStyle,
			btnBorder,
			btnBorderMobile,
			btnBorderTablet,
			btnBorderRadius,
			btnBorderRadiusMobile,
			btnBorderRadiusTablet,
			btnBorderColor,
			btnBorderHoverColor,
			btnBorderType, 
		    btnTextColor,
		    btnTextHoverColor,

		    enableGlimmerEffect,

		} } = props;	
		const Tag1 = titleTag1
		const Tag2 = titleTag2
		let slugName = mainTitle.toString().toLowerCase().replace(/( |<.+?>|&nbsp;)/g, "-");
		let slugSubName = subTitle.toString().toLowerCase().replace(/( |<.+?>|&nbsp;)/g, "-");

		let  totalRow = props.attributes.reviewbox.length;		
		const total = props.attributes.reviewbox.reduce((prev,next) => prev + next.selectedStars,0);
		let finalStarRating = (total/totalRow).toFixed(1);
		let highlightedStars1 = (total/totalRow).toFixed(1);


		let newrel;
        let Isconcated = false
        if( !btnTarget){
            newrel = btnRel
            Isconcated = false
        } else  if( !btnTarget && btnRel === NEW_TAB_REL){
            newrel = btnRel
            Isconcated = false
        } else if ( btnTarget && !btnRel ) {
            newrel = NEW_TAB_REL
            Isconcated = true
        } else {
            newrel = NEW_TAB_REL + ' ' + btnRel
            Isconcated = true
        }
        function removeDuplicateWords (s) {
        	var str = s.split(" ");
          	var result = [];
          	for(var i =0; i < str.length ; i++){
            	if(result.indexOf(str[i]) === -1){
                	result.push(str[i]);
              	} 
          	}
           	return result.join(" ");
        }

        newrel = removeDuplicateWords(newrel).trim()


		const trDisplay = props.attributes.reviewbox.map( ( location, index )  => {
			
			
			let highlightedStars = location.highlightedStars;
			let selectedStars = location.selectedStars;
			
			return <li  key={ index }>					
			
					<div className={`affiliate-star-item`} >
						
							<Fragment>
								<RichText.Content
									tagName= {'span'}
									className={`affiliate-txtbox-title`}
									value = { location.reviewtitle }
								/>
							</Fragment>

							<div
                                className="affiliate-star-review-rating"
                                onMouseLeave={() => this.setState({ highlightedStars: 0 })} >
                                {[...Array(ratings)].map((e, i) => (
                                  <div className={`affiliate-star-item`} key={i}>
                                        {i < (highlightedStars ? highlightedStars : selectedStars) ? (
                                            highlightedStars ? (
                                                highlightedStars - 1 === i ? (
                                                    selectedStars % 1 > 0 ? (
                                                        highlightedStars - selectedStars - 0.5 !== 0 ? (
                                                            <HalfStar fillColor={ratingsColor} />
                                                        ) : (
                                                            <FullStar fillColor={ratingsColor} />
                                                        )
                                                    ) : highlightedStars - selectedStars !== 0 ? (
                                                        <FullStar fillColor={ratingsColor} />
                                                    ) : (
                                                        <HalfStar fillColor={ratingsColor} />
                                                    )
                                                ) : (
                                                    <FullStar fillColor={ratingsColor} />
                                                )
                                            ) : selectedStars - i >= 1 ? (
                                                <FullStar fillColor={ratingsColor} />
                                            ) : (
                                                <HalfStar fillColor={ratingsColor} />
                                            )
                                        ) : (
                                            <EmptyStar fillColor={ratingsColor} />
                                        )}
                                    </div>
                                ))}
                            </div>
						
					</div> 
				</li>;				
		});
		return (
				<div id={`affiliate-style-${block_id}`} className={ props.className }>
					<div  itemscope itemtype="https://schema.org/Product" className={`affiliate-starreview-inner`}>

						<div className={`affiliate-starreview-innerouter`}>

							{ showTitle && showTitle == true &&	
								<RichText.Content
									itemprop="name"
		                            tagName={Tag1}
		                            value={mainTitle}
		                            className="affiliate-starreview-maintitle"
		                            id={slugName}
		                        />
		                    }

							<ul className={`affiliate-starreview-starrating`}>
								{trDisplay}				
							</ul>

							<div className={`affiliate-starreview-footerbox`}>

						<div className={`affiliate-starreview-footerbox-left`}>

							{ showConclusionTitle && showConclusionTitle == true &&		
								<RichText.Content
		                            tagName={Tag2}
		                            value={subTitle}
		                            className="affiliate-starreview-subtitle"
		                            id={slugSubName}
		                        />
		                    }

		                    { showConclusionSummary && showConclusionSummary == true &&		
		                        <div itemprop="description" className={`affiliate-starreview-c_content`}>
			                        <RichText.Content
			                            value={starReviewContent} 
			                            className="affiliate-starreview-content"
			                        />
		                        </div>
		                    }

	                        <div itemprop="aggregateRating" itemscope itemtype="https://schema.org/AggregateRating" className={`affiliate-starreview-footerbox-right`}>
	                        	
	                        	{ showRating && showRating == true &&		
	                      			<Fragment>
		                        	<div className={`affiliate-starreview-total`}><asside itemprop="ratingValue">{finalStarRating}</asside><asside className={`affiliate-starreview-totalcount`}>/</asside><asside className={`affiliate-starreview-totalcount`} itemprop="reviewCount">5</asside></div>	                        	
		                        	<div className="affiliate-star-review-rating">
		                                {[...Array(ratings)].map((e, i) => (
		                                   <div className={`affiliate-star-item`} key={i} >
		                                        {i < (highlightedStars1) ? (
		                                           	finalStarRating - i >= 1 ? (
		                                                <FullStar fillColor={ratingsColor} />
		                                            ) : (
		                                                <HalfStar fillColor={ratingsColor} />
		                                            )
		                                        ) : (
		                                            <EmptyStar fillColor={ratingsColor} />
		                                        )}
		                                    </div>
		                                ))}
		                            </div>
		                            </Fragment>
	                        	}
	                        </div>

	                        </div></div>

	                        <div className={`affiliate-abbtn-inner`}>
	                        { btnShow && btnShow == true &&	
		                        <a href = {btnHref} className={classnames(`affiliate-abbtn btn-is-${btnSize} ${btnWidth === "full"? "btn-is-fullw":btnWidth === "flex" ? `btn-is-flex-${btnSize}`:""} ${bntRounded ? 'btn-is-rounded':''}  ${enableGlimmerEffect ? 'glimmer-effect' : ''}`).trim()}
	                                {...(btnTarget ? {...btnTarget && { rel: newrel }} : { rel: newrel }  )}
	                                {...(btnTarget ? { target: '_blank' } : '' )}
	                                >
	                                { btnIconPosition && btnIconPosition == 'af-icon-is-left' &&
	                                    <i className={`affiliate-abbtn-icon ${btnIcon} ${btnIconPosition}`}></i>
	                                }
	                                <RichText.Content value={btnTitle} />
	                                { btnIconPosition && btnIconPosition == 'af-icon-is-right' &&
	                                    <i className={`affiliate-abbtn-icon ${btnIcon} ${btnIconPosition}`}></i>
	                                }
	                            </a>
	                        }
                            </div>
	                     </div>
					</div>
				</div>
		);
	},
} );
