import classnames from "classnames"
import map from "lodash/map"
import TypographyControl from '../components/typography/index.js';
import WebfontLoader from "../components/typography/fontloader"
import Alignment from '../../components/fields/Alignment.js';
import BoxShadow  from './../../components/fields/BoxShadow.js';
import Color  from '../../components/fields/Color/Color.js';
import Dimension  from '../../components/fields/Dimension/Dimension.js';
import RadioAdvanced from '../../components/fields/RadioAdvanced.js';
import Range from '../../components/fields/Range/Range.js';
import affiliate_styling  from './styling.js';
import BorderTypes  from './../../components/fields/BorderTypes.js';
import ABTOC from './toc3';
import getIcon from '../../icons/get-icon';

const striptags = require('striptags');
const { __ } = wp.i18n;
const { withSelect, withDispatch } = wp.data
const {
    InspectorControls,
    BlockControls,
    RichText
} = wp.blockEditor;

const { compose } = wp.compose

const {
    Component,
    Fragment
} = wp.element;

const {
    PanelBody,
    Toolbar,
    Tooltip,
    TextControl,
    ToggleControl,
    TabPanel,
    Dashicon,
    PanelRow,
    CheckboxControl
} = wp.components;

class Edit extends Component {

    constructor(props) {
        super( ...arguments )
    }
    
    componentDidUpdate(prevProps, prevState) {
      if (
        JSON.stringify( this.props.headers ) !==
        JSON.stringify( prevProps.headers )
      ) {
        this.props.setAttributes({
          headerLinks: JSON.stringify(this.props.headers)
        });
      }
    }

    componentDidMount() {
        this.props.setAttributes({ block_id: this.props.clientId })

        this.props.setAttributes( { headerLinks: JSON.stringify( this.props.headers ) } )

        const $style = document.createElement("style")
        $style.setAttribute("id", "affiliate-style-" + this.props.clientId)
        document.head.appendChild($style)
    }

    render() {
        const {
            name,
            clientId,
            isSelected,
            attributes,
            setAttributes,
            className,
            headers,
            attributes: {
                block_id,
                mappingHeaders,
                align,
                tColumnsDesktop,
                initialCollapse,
                heading,
                headerLinks,
                tColumns,
                scrollToTop,
                boxMargin,
                boxMarginMobile,
                boxMarginTablet,
                boxPadding,
                boxPaddingMobile,
                boxPaddingTablet,
                boxBorder,
                boxBorderMobile,
                boxBorderTablet,
                boxBorderRadius,
                boxBorderRadiusMobile,
                boxBorderRadiusTablet,
                titleTextColor,
                titleLoadGoogleFonts,
                titlefontFamily,
                titlefontSizeDesktop,
                titlefontSizeMobile,
                titlefontSizeTablet,
                titlefontStyle,
                titlefontSubset,
                titlefontWeight,
                titlefontSizeType,
                titlefontSizeTypeMobile,
                titlefontSizeTypeTablet,
                titleletterSpacing,
                titleletterSpacingMobile,
                titleletterSpacingTablet,
                titleletterSpacingType,
                titleletterSpacingTypeTablet,
                titleletterSpacingTypeMobile,
                titlelineHeight,
                titlelineHeightMobile,
                titlelineHeightTablet,
                titletextDecoration,
                titletextTransform,
                cntnLoadGoogleFonts,
                cntnfontFamily,
                cntnfontWeight,
                cntnfontSubset,
                cntnfontSizeType,
                cntnfontSizeTypeMobile,
                cntnfontSizeTypeTablet,
                cntnfontSizeDesktop,
                cntnfontSizeMobile,
                cntnfontSizeTablet,
                cntnlineHeight,
                cntnlineHeightMobile,
                cntnlineHeightTablet,
                cntnletterSpacing,
                cntnletterSpacingMobile,
                cntnletterSpacingTablet,
                cntnletterSpacingType,
                cntnletterSpacingTypeTablet,
                cntnletterSpacingTypeMobile,
                cntntextTransform,
                cntntextDecoration,
                cntnfontStyle,
                cntnTextColor,
                boxBorderType,
                customWidthType,
                customWidthTypeMobile,
                customWidthTypeTablet,
                customWidth,
                customWidthMobile,
                customWidthTablet,
                boxPosition,
                enableCustomWidth,
                borderColor,
                boxBgColor,
                boxShadow,
                numberofColumns,
                numberofColumnsMobile,
                numberofColumnsTablet,
                isCollapsible,
                listType,
                collapsibleType,
                collapseOpenText,
                collapseCloseText,
                toggleIcon,
                isCollapsed,
                titleTextHoverColor,
                mappedHeaders
              }
        } = this.props;
        
        var element = document.getElementById("affiliate-style-" + this.props.clientId)
        if (null != element && "undefined" != typeof element) {
             element.innerHTML = affiliate_styling(this.props, "affiliate-style")
        }

        let loadtitleGoogleFonts
        let loadcntnGoogleFonts
   
        if( titleLoadGoogleFonts == true ) {
            
          const titleconfig = { google: { families: [ titlefontFamily + ( titlefontWeight ? ":" + titlefontWeight : "" ) ], }, }

          loadtitleGoogleFonts = (
            <WebfontLoader config={ titleconfig }></WebfontLoader>
          )
        }
        
        if( cntnLoadGoogleFonts == true ) {
            
          const cntnconfig = { google: { families: [ cntnfontFamily + ( cntnfontWeight ? ":" + cntnfontWeight : "" ) ], }, }

          loadcntnGoogleFonts = (
            <WebfontLoader config={ cntnconfig }></WebfontLoader>
          )
        }
      let icon_html = ''

      const currentIconClass = {};
      switch (toggleIcon) {
          case 'chevron-cirlce':
              currentIconClass.open = 'fas fa-chevron-circle-down';
              currentIconClass.close = 'fas fa-chevron-circle-up';
              break;
          case 'plus':
              currentIconClass.open = 'fas fa-plus';
              currentIconClass.close = 'fas fa-minus';
              break;
          case 'plus-square':
              currentIconClass.open = 'fas fa-plus-square';
              currentIconClass.close = 'fas fa-minus-square';
              break;
          default:
              currentIconClass.open = 'fas fa-angle-down';
              currentIconClass.close = 'fas fa-angle-up';
      }

      if ( isCollapsible ) {
        icon_html = (
          // <span className="affiliate-toc-collapsible-wrap"> { toggleIcon } </span>
          <div
              className='affiliate-toc-collapsible-wrap'
              // onClick={() => setAttributes({ isCollapsed: !isCollapsed })}
          >
              {
                  isCollapsed === true ? (
                      collapsibleType !== 'icon' ? <a href='javascript:;'>{collapseCloseText}</a> : <a href="javascript:;" className={currentIconClass.close}></a>
                  ) : (
                          collapsibleType !== 'icon' ? <a href='javascript:;'>{collapseOpenText}</a> : <a href="javascript:;" className={currentIconClass.open}></a>
                      )
              }
          </div>
        )	
      }

        return (
            <Fragment>
                <InspectorControls key="inspector">

                    <PanelBody title={`General Settings`} initialOpen={false}  icon={ getIcon( 'documentation' ) } className={ 'abblocks-panel-label' }>

                      <ToggleControl
                          label={__('Is Collapsible')}
                          checked={isCollapsible}
                          onChange={() => setAttributes({ isCollapsible: !isCollapsible })}
                        />
                        { isCollapsible && isCollapsible == true &&
                          <Fragment>
                            <ToggleControl
                                label={__('Default Collapsible')}
                                checked={initialCollapse}
                                onChange={() => setAttributes({ initialCollapse: !initialCollapse })}
                              />
                              <RadioAdvanced
                                label={__('Button Type')}
                                options={[
                                    { label: __('Text'), value: 'text', title: __('Text') },
                                    { label: __('Icon'), value: 'icon', title: __('Icon') }
                                ]}
                                value={collapsibleType}
                                onChange={collapsibleType => setAttributes({ collapsibleType })} />
                                {
                                  collapsibleType === 'icon' ? (
                                      <RadioAdvanced
                                          label={__('Icon')}
                                          options={[
                                              { icon: 'fas fa-angle-up', value: 'angle', title: __('Angle') },
                                              { icon: 'fas fa-chevron-circle-up', value: 'chevron-cirlce', title: __('Chevron Circle') },
                                              { icon: 'fas fa-plus', value: 'plus', title: __('Plus/Minus') },
                                              { icon: 'fas fa-plus-square', value: 'plus-square', title: __('Plus/Minus Square') }
                                          ]}
                                          value={toggleIcon}
                                          onChange={toggleIcon => setAttributes({ toggleIcon })} />
                                  ) : (
                                          <Fragment>
                                              <TextControl
                                                  label="Open Text"
                                                  value={collapseOpenText}
                                                  onChange={(collapseOpenText) => setAttributes({ collapseOpenText })} />
                                              <TextControl
                                                  label="Close Text"
                                                  value={collapseCloseText}
                                                  onChange={(collapseCloseText) => setAttributes({ collapseCloseText })} />
                                          </Fragment>

                                      )
                                    }
                          </Fragment>    
                        }

                      <RadioAdvanced
                          label={__('List Type')}
                          options={[
                            { label: 'List', value: 'list', title: 'List' },
                            { label: 'Number', value: 'number', title: 'Number' },
                            { label: 'Icon', value: 'icon', title: 'Icon' },
                          ]}
                        value={listType}
                        onChange={(value) => setAttributes({ listType: value })} />
                      <h2>{ __( "Select the heading to consider when generating the table" ) }</h2>
                      <div className={`affiliate-d-flex`}>
                        <div className={`affiliate-toc-hlist`}>
                                  <CheckboxControl
                                      label={__('H1')}
                                      checked={mappedHeaders['h1']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h1: value } })}
                                  />
                                  <CheckboxControl
                                      label={__('H2')}
                                      checked={mappedHeaders['h2']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h2: value } })}
                                  />
                                  <CheckboxControl
                                      label={__('H3')}
                                      checked={mappedHeaders['h3']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h3: value } })}
                                  />
                                  <CheckboxControl
                                      label={__('H4')}
                                      checked={mappedHeaders['h4']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h4: value } })}
                                  />
                                  <CheckboxControl
                                      label={__('H5')}
                                      checked={mappedHeaders['h5']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h5: value } })}
                                  />
                                  <CheckboxControl
                                      label={__('H6')}
                                      checked={mappedHeaders['h6']}
                                      onChange={value => setAttributes({ mappedHeaders: { ...mappedHeaders, h6: value } })}
                                  />
                            </div>
                      </div>

                       <TabPanel className="affiliate-size-type-field-tabs affiliate-dimension-field mt-align-tab"
                          activeClass="active-tab"
                          tabs={[
                            {
                              name: 'boxdesk',
                              title: <Dashicon icon="desktop" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxtablet',
                              title: <Dashicon icon="tablet" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxmobile',
                              title: <Dashicon icon="smartphone" />,
                              className: 'affiliate-responsive-tabs',
                            },
                          ]}>
                          {
                            (radiustab) => {
                              let tabout;
                              if (radiustab.name) {
                                if ('boxmobile' === radiustab.name) {
                                  tabout = (
                                    <Range label={__('Number of Columns')} value={numberofColumnsMobile} onChange={(value) => setAttributes({ numberofColumnsMobile: value })} min={1} max={1} />
                                  );
                                } else if ('boxtablet' === radiustab.name) {
                                  tabout = (
                                    <Range label={__('Number of Columns')} value={numberofColumnsTablet} onChange={(value) => setAttributes({ numberofColumnsTablet: value })} min={1} max={2} />
                                  );
                                } else {
                                  tabout = (
                                    <Range label={__('Number of Columns')} value={numberofColumns} onChange={(value) => setAttributes({ numberofColumns: value })} min={1} max={3} />
                                  );
                                }
                              }
                              return <div>{tabout}</div>;
                            }
                          }
                        </TabPanel>
                        <ToggleControl
                            label={__('Custom Width')}
                            checked={enableCustomWidth}
                            onChange={() => setAttributes({ enableCustomWidth: !enableCustomWidth })}
                          />


                          { enableCustomWidth && enableCustomWidth == true &&
                          <Fragment>
                            <TypographyControl
                                label={__("Typography")}
                                fontSizeLabel={__('Box Width')}
                                attributes={attributes}
                                setAttributes={setAttributes}
                                disableLineHeight
                                disableFontFamily
                                disableLetterSpacing
                                disableTextTransform
                                disableTextDecoration
                                disableFontStyle
                                maxVal={1000}
                                fontSizeType={{ value: customWidthType, label: __("customWidthType") }}
                                fontSizeTypeMobile={{ value: customWidthTypeMobile, label: __("customWidthTypeMobile") }}
                                fontSizeTypeTablet={{ value: customWidthTypeTablet, label: __("customWidthTypeTablet") }}
                                fontSize={{ value: customWidth, label: __("customWidth") }}
                                fontSizeMobile={{ value: customWidthMobile, label: __("customWidthMobile") }}
                                fontSizeTablet={{ value: customWidthTablet, label: __("customWidthTablet") }}
                              />
                              { customWidth && customWidth !== '' &&
                                <RadioAdvanced
                                  label={__('Box Position')}
                                  options={[
                                    { label: 'Left', value: 'left', title: 'Left' },
                                    { label: 'Center', value: 'center', title: 'Center' },
                                    { label: 'Right', value: 'right', title: 'Right' },
                                  ]}
                                  value={boxPosition}
                                  onChange={(value) => setAttributes({ boxPosition: value })} />
                              }
                          </Fragment>
                        }

                        <BorderTypes label={__('Border Type')} value={boxBorderType} onChange={(value) => setAttributes({ boxBorderType: value })} />


                        <TabPanel className="affiliate-size-type-field-tabs affiliate-dimension-field mt-align-tab"
                          activeClass="active-tab"
                          tabs={[
                            {
                              name: 'boxdesk',
                              title: <Dashicon icon="desktop" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxtablet',
                              title: <Dashicon icon="tablet" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxmobile',
                              title: <Dashicon icon="smartphone" />,
                              className: 'affiliate-responsive-tabs',
                            },
                          ]}>
                          {
                            (radiustab) => {
                              let tabout;
                              if (radiustab.name) {
                                if ('boxmobile' === radiustab.name) {
                                  tabout = (
                                    <Dimension
                                      label={__('Box Border')}
                                      value={boxBorderMobile}
                                      onChange={val => setAttributes({ boxBorderMobile: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                } else if ('boxtablet' === radiustab.name) {
                                  tabout = (
                                    <Dimension label={__('Box Border')} value={boxBorderTablet}
                                      onChange={val => setAttributes({ boxBorderTablet: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                } else {
                                  tabout = (
                                    <Dimension
                                      label={__('Box Border')}
                                      value={boxBorder}
                                      onChange={val => setAttributes({ boxBorder: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                }
                              }
                              return <div>{tabout}</div>;
                            }
                          }
                        </TabPanel>
                        <TabPanel className="affiliate-size-type-field-tabs affiliate-dimension-field mt-align-tab"
                          activeClass="active-tab"
                          tabs={[
                            {
                              name: 'boxdesk',
                              title: <Dashicon icon="desktop" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxtablet',
                              title: <Dashicon icon="tablet" />,
                              className: 'affiliate-responsive-tabs',
                            },
                            {
                              name: 'boxmobile',
                              title: <Dashicon icon="smartphone" />,
                              className: 'affiliate-responsive-tabs',
                            },
                          ]}>
                          {
                            (radiustab) => {
                              let tabout;
                              if (radiustab.name) {
                                if ('boxmobile' === radiustab.name) {
                                  tabout = (
                                    <Dimension
                                      label={__('Border Radius')}
                                      value={boxBorderRadiusMobile}
                                      onChange={val => setAttributes({ boxBorderRadiusMobile: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                } else if ('boxtablet' === radiustab.name) {
                                  tabout = (
                                    <Dimension label={__('Border Radius')} value={boxBorderRadiusTablet}
                                      onChange={val => setAttributes({ boxBorderRadiusTablet: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                } else {
                                  tabout = (
                                    <Dimension
                                      label={__('Border Radius')}
                                      value={boxBorderRadius}
                                      onChange={val => setAttributes({ boxBorderRadius: val })}
                                      min={0}
                                      max={600}
                                      unit={['px','em','rem','%']}
                                      clientId={this.props.clientId}
                                    />
                                  );
                                }
                              }
                              return <div>{tabout}</div>;
                            }
                          }
                        </TabPanel> 

                      <BoxShadow label={__('Box-Shadow')} value={boxShadow} onChange={(value) => setAttributes({ boxShadow: value })} />
                    </PanelBody>

                    <PanelBody title={ __( 'Typography' ) } initialOpen={false}  icon={ getIcon( 'typography' ) } className={ 'abblocks-panel-label' }>
                        <TypographyControl
                          label={__("Title Typography")}
                          attributes={attributes}
                          setAttributes={setAttributes}
                          loadGoogleFonts={{ value:titleLoadGoogleFonts, label: __("titleLoadGoogleFonts") }}
                          fontFamily={{ value: titlefontFamily, label: __("titlefontFamily") }}
                          fontWeight={{ value: titlefontWeight, label: __("titlefontWeight") }}
                          fontSubset={{ value: titlefontSubset, label: __("titlefontSubset") }}
                          fontSizeType={{ value: titlefontSizeType, label: __("titlefontSizeType") }}
                          fontSizeTypeMobile={{ value: titlefontSizeTypeMobile, label: __("titlefontSizeTypeMobile") }}
                          fontSizeTypeTablet={{ value: titlefontSizeTypeTablet, label: __("titlefontSizeTypeTablet") }}
                          fontSize={{ value: titlefontSizeDesktop, label: __("titlefontSizeDesktop") }}
                          fontSizeMobile={{ value: titlefontSizeMobile, label: __("titlefontSizeMobile") }}
                          fontSizeTablet={{ value: titlefontSizeTablet, label: __("titlefontSizeTablet") }}
                          lineHeightType={{ value: '', label: __(" ") }}
                          lineHeight={{ value: titlelineHeight, label: __("titlelineHeight") }}
                          lineHeightMobile={{ value: titlelineHeightMobile, label: __("titlelineHeightMobile") }}
                          lineHeightTablet={{ value: titlelineHeightTablet, label: __("titlelineHeightTablet") }}
                          letterSpacing={{ value: titleletterSpacing, label: __("titleletterSpacing") }}
                          letterSpacingMobile={{ value: titleletterSpacingMobile, label: __("titleletterSpacingMobile") }}
                          letterSpacingTablet={{ value: titleletterSpacingTablet, label: __("titleletterSpacingTablet") }}
                          letterSpacingType={{ value: titleletterSpacingType, label: __("titleletterSpacingType") }}
                          letterSpacingTypeTablet={{ value: titleletterSpacingTypeTablet, label: __("titleletterSpacingTypeTablet") }}
                          letterSpacingTypeMobile={{ value: titleletterSpacingTypeMobile, label: __("titleletterSpacingTypeMobile") }}
                          textTransform={titletextTransform}
                          onTextTransform={(value) => setAttributes({ titletextTransform: value })}
                          textDecoration={titletextDecoration}
                          onTextDecoration={(value) => setAttributes({ titletextDecoration: value })}
                          fontStyle={titlefontStyle}
                          onFontStyle={(value) => setAttributes({ titlefontStyle: value })}
                      />

                      <TypographyControl
                            label={__("Content Typography")}
                            attributes={attributes}
                            setAttributes={setAttributes}
                            loadGoogleFonts={{ value:cntnLoadGoogleFonts, label: __("cntnLoadGoogleFonts") }}
                            fontFamily={{ value: cntnfontFamily, label: __("cntnfontFamily") }}
                            fontWeight={{ value: cntnfontWeight, label: __("cntnfontWeight") }}
                            fontSubset={{ value: cntnfontSubset, label: __("cntnfontSubset") }}
                            fontSizeType={{ value: cntnfontSizeType, label: __("cntnfontSizeType") }}
                            fontSizeTypeMobile={{ value: cntnfontSizeTypeMobile, label: __("cntnfontSizeTypeMobile") }}
                            fontSizeTypeTablet={{ value: cntnfontSizeTypeTablet, label: __("cntnfontSizeTypeTablet") }}
                            fontSize={{ value: cntnfontSizeDesktop, label: __("cntnfontSizeDesktop") }}
                            fontSizeMobile={{ value: cntnfontSizeMobile, label: __("cntnfontSizeMobile") }}
                            fontSizeTablet={{ value: cntnfontSizeTablet, label: __("cntnfontSizeTablet") }}
                            lineHeightType={{ value: '', label: __(" ") }}
                            lineHeight={{ value: cntnlineHeight, label: __("cntnlineHeight") }}
                            lineHeightMobile={{ value: cntnlineHeightMobile, label: __("cntnlineHeightMobile") }}
                            lineHeightTablet={{ value: cntnlineHeightTablet, label: __("cntnlineHeightTablet") }}
                            letterSpacing={{ value: cntnletterSpacing, label: __("cntnletterSpacing") }}
                            letterSpacingMobile={{ value: cntnletterSpacingMobile, label: __("cntnletterSpacingMobile") }}
                            letterSpacingTablet={{ value: cntnletterSpacingTablet, label: __("cntnletterSpacingTablet") }}
                            letterSpacingType={{ value: cntnletterSpacingType, label: __("cntnletterSpacingType") }}
                            letterSpacingTypeTablet={{ value: cntnletterSpacingTypeTablet, label: __("cntnletterSpacingTypeTablet") }}
                            letterSpacingTypeMobile={{ value: cntnletterSpacingTypeMobile, label: __("cntnletterSpacingTypeMobile") }}
                            textTransform={cntntextTransform}
                            onTextTransform={(value) => setAttributes({ cntntextTransform: value })}
                            textDecoration={cntntextDecoration}
                            onTextDecoration={(value) => setAttributes({ cntntextDecoration: value })}
                            fontStyle={cntnfontStyle}
                            onFontStyle={(value) => setAttributes({ cntnfontStyle: value })}
                        />
                    </PanelBody>

                    <PanelBody title={ __( 'Colors' ) } initialOpen={false}  icon={ getIcon( 'colors' ) } className={ 'abblocks-panel-label' }>
                      <Color label={__('Title Color')} disableAlpha value={titleTextColor} onChange={val => setAttributes({ titleTextColor: val })} />
                      <Color label={__('Box Background Color')} disableAlpha value={boxBgColor} onChange={val => setAttributes({ boxBgColor: val })} />
                      <Color label={__('Border Color')} disableAlpha value={borderColor} onChange={val => setAttributes({ borderColor: val })} />

                      <Color label={__('Content Color')} disableAlpha value={cntnTextColor} onChange={val => setAttributes({ cntnTextColor: val })} />
                      <Color label={__('Content Hover Color')} disableAlpha value={titleTextHoverColor} onChange={val => setAttributes({ titleTextHoverColor: val })} />

                    </PanelBody>

                   
                </InspectorControls>
                
                <div id={`affiliate-style-${block_id}`} className={ classnames( className, `affiliate-toc-align-${align}`, `affiliate-toc-columns-${tColumnsDesktop}`, ( initialCollapse ) ? `` : 'affiliate-toc-collapse',
                      `affiliate-block-${ this.props.clientId.substr( 0, 8 ) }` )}
                      onClick={() => setAttributes({ isCollapsed: !isCollapsed })}    
                      >
                    <div className={`affiliate-toc-inner affiliate-toc-is${listType} affiliate-toc-align-${boxPosition}`}>
                      <div className="affiliate-toc-wrap">
                        <div className="affiliate-toc-title-wrap">
                            <RichText
                              tagName= { "div" }
                              placeholder={ __( "Table Of Contents" ) }
                              value={ heading }
                              className = 'affiliate-toc-title'
                              onChange = { ( value ) => setAttributes( { heading: value } ) }
                              multiline={ false }
                              onRemove={ () => props.onReplace( [] ) }
                            />
                            {icon_html}
                        </div>
                        <ABTOC
                              headers={headerLinks && JSON.parse(headerLinks)}
                              blockProp={this.props}
                        />
                      </div>    
                    </div>
                </div>
                {loadtitleGoogleFonts}
                {loadcntnGoogleFonts}
            </Fragment>
        )
    }       
}

export default compose(
	withSelect( ( select, ownProps ) => {

		const getData = ( headerData, a ) => {
			headerData.map( ( header ) => {
				let innerBlock = header.innerBlocks;
				if( innerBlock.length > 0 ) {
					innerBlock.forEach(function(element) {
						if( element.innerBlocks.length > 0 ) {
							getData( element.innerBlocks, a );
						} else {
							if( element.name === 'core/heading' ) {
								a.push( element );
							}
						}
					});
				} else {
					if( header.name === 'core/heading' ) {
						a.push( header );
					}
				}
			});
			return a; 
		}

		const parseTocSlug = ( slug ) => {

			// If not have the element then return false!
			if( ! slug ) {
				return slug;
			}
			
			var parsedSlug = slug.toString().toLowerCase()
				.replace(/&(amp;)/g, '')					 // Remove &
				.replace(/&(mdash;)/g, '')					 // Remove long dash
				.replace(/\u2013|\u2014/g, '')				 // Remove long dash
				.replace(/[&]nbsp[;]/gi, '-')                // Replace inseccable spaces
				.replace(/\s+/g, '-')                        // Replace spaces with -
				.replace(/[&\/\\#,^!+()$~%.'":*?<>{}@‘’”“]/g, '')  // Remove special chars
				.replace(/\-\-+/g, '-')                      // Replace multiple - with single -
				.replace(/^-+/, '')                          // Trim - from start of text
				.replace(/-+$/, '');                         // Trim - from end of text

			return decodeURI( encodeURIComponent( parsedSlug ) );
		}

		let a = [];
		let all_headers = getData( select( 'core/block-editor' ).getBlocks(), a );

		let headers = [];

		if( all_headers != 'undefined' ) {
			all_headers.forEach((heading, key) => {

				let heading_attr = heading.attributes

				const contentLevel = heading_attr.level

				const contentName = 'content';

				const headingContentEmpty = typeof heading_attr[contentName] === 'undefined' || heading_attr[contentName] === '';
        // console.log(headingContentEmpty)
				if ( !headingContentEmpty ) {
					headers.push(
						{
							tag: contentLevel,
							text: striptags( heading_attr[contentName] ),
							link: parseTocSlug( striptags( heading_attr[contentName] ) ),
							content: heading_attr[contentName]
						}
					);
				}
			});
		}

		if ( headers !== undefined ) {

			headers.forEach( function ( heading, index ) {
				heading.level = 0;

				for ( var i = index - 1; i >= 0; i-- ) {
					var currentOrderedItem = headers[i];

					if ( currentOrderedItem.tag <= heading.tag ) {
						heading.level = currentOrderedItem.level;

						if ( currentOrderedItem.tag < heading.tag ) {
							heading.level++;
						}
						break;
					}
				}
			});
		}

		return {
      headers: headers
		};
	} )
) ( Edit )
