<?php

/**
 * Affiliate Booster functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Affiliate_Booster
 */

if (!function_exists('affiliatebooster_setup')) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function affiliatebooster_setup()
	{
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Affiliate Booster, use a find and replace
		 * to change 'affiliatebooster' to the name of your theme in all the template files.
		 */
		load_theme_textdomain('affiliatebooster', get_template_directory() . '/languages');

		// Add default posts and comments RSS feed links to head.
		add_theme_support('automatic-feed-links');

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support('title-tag');
		add_theme_support( "custom-background" );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support('post-thumbnails');

		/*
		* Gutenberg support
		*/
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'align-wide' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support('editor-styles');
		add_editor_style( 'dist/css/editor-style.min.css' );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
				'style',
				'script',
			)
		);

		// Set up the WordPress core custom background feature.
		add_theme_support(
			'custom-background',
			apply_filters(
				'affiliatebooster_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);
		// Add theme support for selective refresh for widgets.
		add_theme_support('customize-selective-refresh-widgets');
	}

endif;
add_action('after_setup_theme', 'affiliatebooster_setup');

add_action( 'after_setup_theme',  'font_add_all_variants', 100 );

function font_add_all_variants() {
if ( class_exists( 'Kirki_Fonts_Google' ) ) {
Kirki_Fonts_Google::$force_load_all_variants = true;
}
}
/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function affiliatebooster_content_width()
{
	
	$GLOBALS['content_width'] = apply_filters('affiliatebooster_content_width', 640);
}
add_action('after_setup_theme', 'affiliatebooster_content_width', 0);

/**
 * Enqueue scripts and styles.
 */
function affiliatebooster_scripts()
{
	//not minify version css
	wp_enqueue_style('affiliatebooster-style', get_stylesheet_uri(), array(), THEME_VERSION);
	//wp_enqueue_style( 'affiliatebooster-style', get_template_directory_uri() . '/dist/css/style.min.css', array(), THEME_VERSION);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
}
add_action('wp_enqueue_scripts', 'affiliatebooster_scripts');

/**
 * Implement HTML Compression.
 */
if ( !is_user_logged_in() ) {
	add_action('get_header', 'pt_html_minify_start');
	function pt_html_minify_start()  {
		ob_start( 'pt_html_minyfy_finish' );
	}
	function pt_html_minyfy_finish( $html )  {
	$html = preg_replace('/<!--(?!s*(?:[if [^]]+]|!|>))(?:(?!-->).)*-->/s', '', $html);
	$html = str_replace(array("\r\n", "\r", "\n", "\t"), '', $html);
	while ( stristr($html, '  '))
		$html = str_replace('  ', ' ', $html);
	return $html;
	}
}

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Kirki TGM Plugin notice after theme activation.
 */
require get_template_directory() . '/inc/kirki_function.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}

//----------------------NEW-------------------------------//

function my_theme_enqueue_styles()
{
	wp_enqueue_style('responsive', get_template_directory_uri() . '/dist/css/responsive.min.css');
	wp_enqueue_style('bootstrap', get_template_directory_uri() . '/libs/bootstrap-4.5.2-dist/css/bootstrap.min.css');
	wp_enqueue_style('fronted-style', get_template_directory_uri() . '/css/frontend-style.css');

	if ( class_exists( 'woocommerce' ) ) {
		wp_enqueue_style('affbooster-woocommerce-style', get_template_directory_uri() . '/css/woocommerce-style.css');
	}                           
	
	wp_enqueue_style('fontello-affiliatebooster-icons-css', get_template_directory_uri() . '/libs/fontello-affiliatebooster-icons/css/affiliatebooster-icons.css');
	wp_enqueue_script('aff-custom-script', get_template_directory_uri() . '/dist/js/main.min.js', array('jquery'));

}
add_action('wp_enqueue_scripts', 'my_theme_enqueue_styles');

add_action('admin_enqueue_scripts','admin_function');
function admin_function(){
	wp_enqueue_script( 'admin_script', get_template_directory_uri() . '/js/admin_script.js' );
}

//Image Sizes
add_image_size( 'big-featured-image', 1200, 648 );
add_image_size( 'small-featured-image', 830, 448 );
add_image_size( 'related-featured-image', 300, 162 );
add_image_size( 'sidebar-featured-image', 120, 65 );
add_image_size( 'grid-featured-image', 500, 270, true );
add_image_size('aff-booster-recent-thumbnails', 55, 55, true);

// add_theme_support('post-thumbnails');
function wpdocs_custom_excerpt_length($length)
{
	return 30;
}
add_filter('excerpt_length', 'wpdocs_custom_excerpt_length', 999);

function load_custom_wp_admin_style()
{
	wp_register_style('custom_wp_admin_css', get_template_directory_uri() . '/dist/css/admin-style.min.css', false, '1.0.0');
	wp_enqueue_style('custom_wp_admin_css');
}
add_action('admin_enqueue_scripts', 'load_custom_wp_admin_style');

/**
 * Metabox in posts additions.
 */

include(get_template_directory() . '/elements/aff_booster_elements_metabox.php');
include(get_template_directory() . '/elements/aff_boostre_embed_metabox.php');

/**
 * Author Extra.
 */
require get_template_directory() . '/inc/author-extra.php';

/**
 * Widgets.
 */
require get_template_directory() . '/inc/widgets.php';
require get_template_directory() . '/inc/widgets-area.php';

/**
 * Markups.
 */
require get_template_directory() . '/inc/markup.php';

/**
 * Options.
 */
require get_template_directory() . '/inc/options.php';

/**
 * Kirki Customizer.
 */
include_once get_theme_file_path('inc/class-kirki-installer-section.php');
require get_template_directory() . '/inc/customizer-kirki.php';

/**
 * Custom get_the_excerpt.
 */
function the_excerpt_max_charlength( $charlength ){
	$excerpt = get_the_excerpt();
	//$charlength++;
	if ($charlength == 0) {
		echo '';
	}
	else if ( mb_strlen( $excerpt ) > $charlength ) {
		$subex = mb_substr( $excerpt, 0, $charlength - 5 );
		$exwords = explode( ' ', $subex );
		$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
		if ( $excut < 0 ) {
			echo mb_substr( $subex, 0, $excut );
		} else {
			echo $subex;
		}
		echo '...';
		//echo '[...]';
	}
	else {
		echo $excerpt;
	}
}

/* Theme Shortcodes */
function sitename_link_shortcode() {
	$site_name = get_option('blogname');
	$home_url = get_home_url();
	return "<a href='".$home_url."' target='_blank' rel='nofollow'>".$site_name."</a>";
}
add_shortcode('sitename', 'sitename_link_shortcode');

function year_footer_shortcode() {
	return date('Y');
}
add_shortcode('year', 'year_footer_shortcode');

function affiliatebooster_link_shortcode() {
	$affiliatebooster_link = esc_html('https://www.affiliatebooster.com/');
	return '<a href="'. $affiliatebooster_link .'" target="_blank" rel="nofollow">AffiliateBooster Theme</a>';
}
add_shortcode('affiliatebooster', 'affiliatebooster_link_shortcode');

/**
 * Theme License.
 */
$test_license = '';
$license_data = '';
define('DT_KEY', 'affiliate_booster_theme_license_key_status');
define('AFFILIATE_BOOSTER_THM_SL_STORE_URL', 'https://store.affiliatebooster.com/'); /* IMPORTANT: Do not modify this line of code, the theme could stop working correctly */
define('AFFILIATE_BOOSTER_SL_THEME_NAME', 'affiliatebooster'); /* IMPORTANT: Do not modify this line of code, the theme could stop working correctly */
define('AFFILIATE_BOOSTER_SL_THEME_ITEM_ID', 8123);
$theme = wp_get_theme();

if (!defined('THEME_VERSION')) {
	// Replace the version number of the theme on each release.
	// define( 'THEME_VERSION', '1.0.0' );
	define('THEME_VERSION', $theme->Version);
}

if (!class_exists('AFFILIATE_BOOSTER_SL_Theme_Updater')) {
	include(dirname(__FILE__) . '/theme_updater.php');
}
function affiliate_booster_sl_theme_updater()
{	
	$theme = wp_get_theme();
	$version = $theme->Version;
	$test_license = trim(get_option('affiliate_booster_theme_license_key'));
	//fix error

	$edd_updater = new AFFILIATE_BOOSTER_SL_Theme_Updater(array(
		'remote_api_url' 	=> AFFILIATE_BOOSTER_THM_SL_STORE_URL,
		'version' 			=> $version, /* IMPORTANT: Do not modify this line of code, the theme could stop working correctly */
		'license' 			=> $test_license,
		'item_id' 			=> 	AFFILIATE_BOOSTER_SL_THEME_ITEM_ID,
		'author'			=> ''
	)); /* IMPORTANT: Do not modify this line of code, the theme could stop working correctly */
}
add_action('admin_init', 'affiliate_booster_sl_theme_updater');

add_action('admin_menu', 'add_affiliate_booster_license_menu');
function add_affiliate_booster_license_menu()
{
	add_theme_page('Theme License', 'Theme License', 'manage_options', 'affiliatebooster', 'affiliate_booster_theme_license_page');
}
include(dirname(__FILE__) . '/license/license.php');

function affiliate_booster_theme_license_page()
{
	$license 	= get_option('affiliate_booster_theme_license_key');
	$status 	= get_option('affiliate_booster_theme_license_key_status');
	?>
	<div id="acera-content" class="affiliate-activation-wrapper tab-content" style="display: block;">
		<h2><?php _e('Affiliate Booster Theme License Key', 'affiliatebooster'); ?></h2>		 
		 
		 <table class="form-table">
			<tbody>
				<tr valign="top">
					<th scope="row" valign="top">
						<?php _e('License Key', 'affiliatebooster'); ?><br><br>
					
						<?php  
						if(isset($license) && $license != ''){
							$license_length = strlen($license);
							$license_output = substr_replace($license, str_repeat('X', $license_length - 4), 0, $license_length - 4);
						}else{
							$license_output = '';
						}
						?>
						<?php echo esc_attr($license_output); ?>
						<?php if($license != '' ){ 
							if($status == 'valid') { ?>
							<!-- <span style="color:green;"><?php _e('Active','affiliatebooster'); ?></span>  -->
						<?php } else { ?>
							<span style="color:red;"><?php _e('Inactive','affiliatebooster'); ?></span>
						<?php } }else{ ?> 									
							<span style="color:red;"><?php _e('Please activate your copy of the Affiliate Booster Theme to get update notifications, access to support features & other resources!','affiliatebooster'); ?></span>
						<?php } ?>
					</th>
				</tr>
				 
			</tbody>
		</table>  

		<?php if(isset($license) && $license == ''){ ?>
			<form action="<?php echo AFFILIATE_BOOSTER_THM_SL_STORE_URL ?>auth/" method="get">
				<input type="hidden" name="dmverify" value="<?php echo base64_encode(get_site_url()) ?>"> 
				<input type="hidden" name="themeactive" value="<?php echo base64_encode('yes') ?>">
				<input class="grdiant-btn" style="border:0px; cursor: pointer;" type="submit" name="active" value="Connect Your Account">
			</form>
		<?php }else{ ?>
			<form action="" method="POST">
				<?php wp_nonce_field( 'affiliate_booster_themes_nonce', 'affiliate_booster_themes_nonce' ); ?>
				<input type="submit" class="grdiant-btn" style="border:0px; cursor: pointer;"  name="affiliate_booster_theme_license_deactivate" value="<?php _e('Deactivate License', 'affiliatebooster'); ?>"/>
				<input type="hidden" name="affiliate_license_status" value="deactive"/>
			</form>
		<?php } ?>

	</div>
	<style>
		.grdiant-btn {
		    background: rgb(175,59,173);
		    background: linear-gradient(90deg, rgba(175,59,173,1) 0%, rgba(208,65,132,1) 100%);
		    color: #fff;
		    border-radius: 30px;
		    width: 100%;
		    display: block;
		    line-height: 40px;
		    font-size: 16px;
		    text-align: center;
		    margin: 20px auto;
		    text-decoration: none;
		}
	</style>
	<?php
	}

	function affiliate_booster_theme_register_option()
	{
		register_setting('affiliate_booster_theme_license', 'affiliate_booster_theme_license_key', 'affiliate_booster_theme_sanitize_license');
	}
	add_action('admin_init', 'affiliate_booster_theme_register_option');

	function affiliate_booster_theme_sanitize_license($new)
	{
		$old = get_option('affiliate_booster_theme_license_key');
		if ($old && $old != $new) {
			delete_option('affiliate_booster_theme_license_key_status');
		}
		return $new;
	}
	// Activate license key
	function affiliate_booster_theme_activate_license()
	{
		if (isset($_POST['affiliate_booster_theme_license_activate'])) {
			if (!check_admin_referer('affiliate_booster_themes_nonce', 'affiliate_booster_themes_nonce'))
				return;
			global $wp_version;
			$license = trim(get_option('affiliate_booster_theme_license_key'));
			$api_params = array(
				'edd_action' => 'activate_license',
				'license' => $license,
				'item_id' => urlencode(AFFILIATE_BOOSTER_SL_THEME_ITEM_ID)
			);
			$response = wp_remote_get(add_query_arg($api_params, AFFILIATE_BOOSTER_THM_SL_STORE_URL), array('timeout' => 15, 'sslverify' => false));
			
			$license_data = json_decode(wp_remote_retrieve_body($response));
			
			if (is_wp_error($response)){
				return false;
			}
			else {

				$license_data = json_decode( wp_remote_retrieve_body( $response ) );
				
				if ( false === $license_data->success || 0 == $license_data->success ) {
					
					// switch( property_exists($license_data,'error')) {
					switch( $license_data->error) {
	
						case 'expired' :
	
							$message = sprintf(
								__( 'Your <i><b> Affiliate Booster Theme </b></i> license has expired on %s. Please renew to get theme updates.', 'affiliatebooster' ),
								date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
							);
							break;
	
						case 'revoked' :
	
							$message = __( 'Admin has disabled your <i><b> Affiliate Booster Theme </b></i> license key. Please contact AffiliateBooster support.' ,'affiliatebooster');
							break;
	
						case 'missing' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> Invalid license.' ,'affiliatebooster');
							break;
	
						case 'invalid' :
						case 'site_inactive' :
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license is not active for this URL.', 'affiliatebooster');
							break;
	
						case 'item_name_mismatch' :
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license key is not matched.' , 'affiliatebooster');
							break;
	
						case 'no_activations_left':
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license activation limit has exceeded. Please buy more license keys or remove your site(s) from your dashboard.', 'affiliatebooster' );
							break;
						
						case 'disabled' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> Admin has disabled your license key. Please contact AffiliateBooster support.' , 'affiliatebooster');
							break;
	
						case 'invalid_item_id' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> license key is not valid for this item.' , 'affiliatebooster' );
							break;
	
						default :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> An error occurred, please try again.', 'affiliatebooster' );
							break;
					}
				}
				
				if($license_data->license){
					switch($license_data->license){
						case 'valid' :
						update_option('affiliate_booster_theme_license_key_status', $license_data->license);
						$message = '';
						$base_url = admin_url( 'themes.php?page=affiliatebooster' );
						$redirect = add_query_arg( array( 'theme_sl_activation' => 'true', 'message' => urlencode( $message ) ), $base_url );
						wp_redirect( $redirect );
						exit();
						break;

						default :
						break;
					}
				}
			}
			// Check if anything passed on a message constituting a failure
			if ( !empty( $message ) ) {
				$base_url = admin_url( 'themes.php?page=affiliatebooster' );
				$redirect = add_query_arg( array( 'theme_sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );
				wp_redirect( $redirect );
				exit();
			}
		}
	}
	add_action('admin_init', 'affiliate_booster_theme_activate_license');

	// deactivate current license
	function affiliate_booster_theme_deactivate_license()
	{
		if (isset($_POST['affiliate_booster_theme_license_deactivate'])) {
			if (!check_admin_referer('affiliate_booster_themes_nonce', 'affiliate_booster_themes_nonce'))
				return;

			$license = trim(get_option('affiliate_booster_theme_license_key'));
			$api_params = array(
				'edd_action' => 'deactivate_license',
				'license' 	=> $license,
				'item_id' => urlencode(AFFILIATE_BOOSTER_SL_THEME_ITEM_ID)
			);

			$response = wp_remote_get(add_query_arg($api_params, AFFILIATE_BOOSTER_THM_SL_STORE_URL), array('timeout' => 15, 'sslverify' => false));
			if (is_wp_error($response)){ return false; }

			$license_data = json_decode(wp_remote_retrieve_body($response));
			if ($license_data->license == 'deactivated' || $license_data->license == 'failed')
				delete_option('affiliate_booster_theme_license_key');
				delete_option('affiliate_booster_theme_license_key_status');
				$message = '';
				$base_url = admin_url( 'themes.php?page=affiliatebooster' );
				$redirect = add_query_arg( array( 'theme_sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );
				wp_redirect( $redirect );
				exit();
		}
	}
	add_action('admin_init', 'affiliate_booster_theme_deactivate_license');


// Check the license key
	function affiliate_booster_theme_check_license()
	{
		global $wp_version;
		$license = trim(get_option('affiliate_booster_theme_license_key'));
		$api_params = array(
			'edd_action' => 'check_license',
			'license' => $license,
			'item_id' => urlencode(AFFILIATE_BOOSTER_SL_THEME_ITEM_ID)
		);
		$response = wp_remote_get(add_query_arg($api_params, AFFILIATE_BOOSTER_THM_SL_STORE_URL), array('timeout' => 15, 'sslverify' => false));
		if (is_wp_error($response))
			return false;

		$license_data = json_decode(wp_remote_retrieve_body($response));
		if ($license_data->license == 'valid') {
			return true;
		}
	}


/**
 * This is a means of catching errors from the activation method above and displaying it to the customer
 */
function affiliate_booster_theme_notices() {
	if ( isset( $_GET['theme_sl_activation'] ) && ! empty( $_GET['message'] ) ) {

		switch( $_GET['theme_sl_activation'] ) {

			case 'false':
				$message = urldecode( $_GET['message'] );
				?>
				<!--<div class="notice is-dismissible notice-error">
					<p><?php echo $message; ?></p>
				</div>-->
				<?php
				break;

			case 'true':
				$message = sprintf(__('Item Activated Successfully','affiliatebooster'));
			?>
			<div class="notice is-dismissible notice-success">
					<p><?php echo $message; ?></p>
			</div>
			<?php
			default:
				// Developers can put a custom success message here for when activation is successful if they way.
				break;

		}
	}
}
add_action( 'admin_notices', 'affiliate_booster_theme_notices' );



/**
 * Display activation notice 
 */
function affiliate_check_theme_activation(){
	$license = trim( get_option( 'affiliate_booster_theme_license_key' ) );
	$licence_status = get_option( 'affiliate_booster_theme_license_key_status');
	
	$is_multisite     = is_multisite();
	$is_network_admin = is_network_admin();
	if ( is_multisite() ) {
		$url =  network_admin_url( 'themes.php?page=affiliatebooster' );
	} else {
		$url =  admin_url( 'themes.php?page=affiliatebooster');
	}
	
	if($licence_status == '' && $license == ''){
		$message = sprintf(__( 'Please', 'affiliatebooster' )) . ' <a href="' . $url . '" class="affiliate-core-license-form-btn">' 
				. sprintf(__( 'activate', 'affiliatebooster' )) . '</a> ' . sprintf(__( 'your copy of the', 'affiliatebooster' )) . ' <i><b> Affiliate Booster Theme </b></i> ' 
				. sprintf(__( 'to get update notifications, access to support features & other resources!', 'affiliatebooster' ));
		if(empty($license) || ( $is_multisite && $is_network_admin ) && !$is_multisite || $licence_status == 'invalid' ){
			echo '<div class="notice is-dismissible notice-warning"> <p> '. $message . '</p> </div>';
		}	
	}
	
	if($license != ''){
		
		global $wp_version;
		$license = trim(get_option('affiliate_booster_theme_license_key'));
		$api_params = array(
			'edd_action' => 'activate_license',
			'license' => $license,
			'item_id' => urlencode(AFFILIATE_BOOSTER_SL_THEME_ITEM_ID)
		);
		$response = wp_remote_get(add_query_arg($api_params, AFFILIATE_BOOSTER_THM_SL_STORE_URL), array('timeout' => 15, 'sslverify' => false));
		$license_data = json_decode(wp_remote_retrieve_body($response));
		if (is_wp_error($response)){
				return false;
			}
			else {

				$license_data = json_decode( wp_remote_retrieve_body( $response ) );
				
				if ( false === $license_data->success || 0 == $license_data->success ) {
					
					// switch( property_exists($license_data,'error')) {
					switch( $license_data->error) {
	
						case 'expired' :
	
							$message = sprintf(
								__( 'Your <i><b> Affiliate Booster Theme </b></i> license has expired on %s. Please renew to get theme updates.', 'affiliatebooster' ),
								date_i18n( get_option( 'date_format' ), strtotime( $license_data->expires, current_time( 'timestamp' ) ) )
							);
							break;
	
						case 'revoked' :
	
							$message = __( 'Admin has disabled your <i><b> Affiliate Booster Theme </b></i> license key. Please contact AffiliateBooster support.' ,'affiliatebooster');
							break;
	
						case 'missing' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> Invalid license.' ,'affiliatebooster');
							break;
	
						case 'invalid' :
						case 'site_inactive' :
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license is not active for this URL.', 'affiliatebooster');
							break;
	
						case 'item_name_mismatch' :
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license key is not matched.' , 'affiliatebooster');
							break;
	
						case 'no_activations_left':
	
							$message = __( 'Your <i><b> Affiliate Booster Theme </b></i> license activation limit has exceeded. Please buy more license keys or remove your site(s) from the your dashboard.', 'affiliatebooster' );
							break;
						
						case 'disabled' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> Admin has disabled your license key. Please contact AffiliateBooster support.' , 'affiliatebooster');
							break;
	
						case 'invalid_item_id' :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> license key is not valid for this item.' , 'affiliatebooster' );
							break;
	
						default :
	
							$message = __( '<i><b> Affiliate Booster Theme </b></i> An error occurred, please try again.', 'affiliatebooster' );
							break;
					}
					
					echo '<div class="notice is-dismissible notice-error"> <p> '. $message . '</p> </div>';
					
				}
				
				
			}
	}
	
}

add_action( 'admin_notices', 'affiliate_check_theme_activation', 1000 );
add_action( 'network_admin_notices', 'affiliate_check_theme_activation', 1000 );



function wpdocs_enqueue_custom_admin_style() {
	wp_enqueue_style( 'admin-customizer', get_template_directory_uri() . '/css/admin-customizer-style.css' );
}
add_action( 'admin_enqueue_scripts', 'wpdocs_enqueue_custom_admin_style' );

/*
* Remove "Site Identity" section from Customize setting.
*/
function affiliate_booster_customize_register() {     
  global $wp_customize;
  $wp_customize->remove_section( 'title_tagline' );  //Modify this line as needed  
}

add_action( 'customize_register', 'affiliate_booster_customize_register', 11 );


add_action("wp_footer","add_class_some_function");

function add_class_some_function()
{
?>
<script type="text/javascript">
		jQuery(document).ready(function(){
		if( jQuery('body.logged-in').hasClass('customize-partial-edit-shortcuts-shown') ){
	        jQuery('main#content .row').addClass('my_customizer_resize');
		}
	});
</script>

<?php
}

/* For Remove Related Products*/
remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );




add_action( 'init', 'woo_remove_wc_breadcrumbs' );
function woo_remove_wc_breadcrumbs() {
remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20, 0 );
}



// shop page grid
add_filter('loop_shop_columns', 'loop_columns', 999);
if (!function_exists('loop_columns')) {
	function loop_columns() {
		return 3; // 3 products per row
	}
}


function theme_licence_update_hook() {
    if(isset($_REQUEST['theme_sl_activation']) && $_REQUEST['theme_sl_activation'] == 'success'){    
        update_option( 'affiliate_booster_theme_license_key', $_REQUEST['key'] );
        update_option( 'affiliate_booster_theme_license_key_status', $_REQUEST['st'] );
        echo 'success';exit;
    }
}
add_action('wp_head', 'theme_licence_update_hook');