<?php
/**
 * Affiliate Booster Theme Customizer
 *
 * @package Affiliate_Booster
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function affiliatebooster_customize_register( $wp_customize ) {
	$wp_customize->remove_control("blogdescription");
	
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'affiliatebooster_customize_partial_blogname',
			)
		);
		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'affiliatebooster_customize_partial_blogdescription',
			)
		);
	}
	
$wp_customize->add_setting( 'tsum_options[hide_title]', array(
    'default'    => false,
	'capability' => 'edit_theme_options',
	'sanitize_callback'  => 'esc_attr'
    ));

    // FRONT BOX CHECK - CONTROL
    $wp_customize->add_control( 'hide_title', array(
    'label'      => 'Hide Title',
    'section'    => 'title_tagline',
    'settings'   => 'tsum_options[hide_title]',
    'type'       => 'checkbox',
    //'priority'   => 20,
    ));  
    $wp_customize->add_setting(
			'blogdescription',
			array(
				'default'    => get_option( 'blogdescription' ),
				'type'       => 'option',
				'capability' => 'manage_options',
				'sanitize_callback'  => 'esc_attr'
			)
		);

		$wp_customize->add_control(
			'blogdescription',
			array(
				'label'   => __( 'Tagline', 'affiliatebooster' ),
				'section' => 'title_tagline',
			)
		);
    
$wp_customize->add_setting( 'tsum_options[hide_tagline]', array(
    'default'    => false,
	'capability' => 'edit_theme_options',
	'sanitize_callback'  => 'esc_attr'
    ));

    // FRONT BOX CHECK - CONTROL
    $wp_customize->add_control( 'hide_tagline', array(
    'label'      => 'Hide Tagline',
    'section'    => 'title_tagline',
    'settings'   => 'tsum_options[hide_tagline]',
    'type'       => 'checkbox',
    //'priority'   => 20,
    )); 
// Display Site Title
$wp_customize->add_setting( 'display_site_title', array(
    'default'           => false,
	'transport'         => 'postMessage',
	'sanitize_callback'  => 'esc_attr'
) );
$wp_customize->add_control( 'display_site_title', array(
    'label'             => __( 'Display Site Title', 'affiliatebooster' ),
    'type'              => 'checkbox',
	'section'    => 'title_tagline',
    'settings'   => 'tsum_optiot',
) );
	
$wp_customize->add_setting( 'aff_logo', array(
	'default'     => get_template_directory_uri().'/images/aff-booster-logo.png',
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'aff_logo', array(
	'label'    => __( 'Site Logo ', 'affiliatebooster' ),
	'description' => __( '<b>Recommended Logo Size: 220px x 100px</b>', 'affiliatebooster' ),
	'section'  => 'title_tagline',
	'settings' => 'aff_logo',
) ) );

	
}
add_action( 'customize_register', 'affiliatebooster_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function affiliatebooster_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function affiliatebooster_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function affiliatebooster_customize_preview_js() {
	wp_enqueue_script( 'affiliatebooster-customizer', get_template_directory_uri() . '/dist/js/customizer.min.js', array( 'customize-preview' ), '_S_VERSION', true );
}
add_action( 'customize_preview_init', 'affiliatebooster_customize_preview_js' );

//------------------------------NEW-----------------------------------//

/**
 * Add Default Font (Google Font - Poppins).
 */
function wdm_load_fonts() {
	wp_register_style( 'wdm-googleFonts-single', '//fonts.googleapis.com/css?family=Poppins');
	wp_enqueue_style( 'wdm-googleFonts-single' );
}
add_action( 'wp_print_styles', 'wdm_load_fonts' );
add_action( 'admin_enqueue_scripts', 'wdm_load_fonts' );

function afftheme_fixed_header()
{
	$top_head = get_theme_mod( 'aff_header_setting_fixed_top', false );
	$mid_head = get_theme_mod( 'aff_header_sticky_settings', false );
	$bot_head = get_theme_mod( 'aff_header_setting_fixed', false );

	if ( true == $top_head ) { 
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(window).scroll(function(){

				var sticky = jQuery('header#header .top-header-parent');
				var mob_sticky = jQuery('header#header .above-header-mobile-menu');
				var scroll = jQuery(window).scrollTop();

				if (scroll >= 100){
					sticky.addClass('fixed_top_nav');
					/*mob_sticky.addClass('fixed_top_nav');*/
				}else{
					sticky.removeClass('fixed_top_nav');
					/*mob_sticky.removeClass('fixed_top_nav');*/
				} 
			});
		});
	</script>
	<style>
		.top-header-parent.fixed_top_nav {
		    padding: 0;
		}
		
		@media (min-width: 768px) and (max-width: 1024px) {
			.top-header-parent.fixed_top_nav .above-header-mobile-menu {
			    padding-top: 5px;
			}
		}
		@media (min-width: 320px) and (max-width: 480px) {
			.top-header-parent.fixed_top_nav .col-4 {
			    padding-top: 3px;
			}		  
		}
		/*@media only screen and (max-width: 1023px) {
			.above-header-menu.fixed_top_nav.active {
			    position: fixed !important;
			    top: 27px;
			}
		}*/
	</style>	
	<?php 
	}

	if ( true == $mid_head ) { 
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(window).scroll(function(){

				var sticky = jQuery('header#header .aff-header-wrapper.desktop');
				var mob_sticky = jQuery('header#header .flex_menu.header1');
				var sticky3 = jQuery('header#header .aff-header-3 .aff-header-wrapper');
				var sticky5 = jQuery('header#header .aff-header-5 .aff-header-wrapper');
				var scroll = jQuery(window).scrollTop();

				if (scroll >= 100){
					sticky.addClass('fixed_mid_nav');
					mob_sticky.addClass('fixed_mid_drop_nav');
					sticky3.addClass('fixed_mid_nav_3');
					sticky5.addClass('fixed_mid_nav_5');
				}else{
					sticky.removeClass('fixed_mid_nav');
					mob_sticky.removeClass('fixed_mid_drop_nav');
					sticky3.removeClass('fixed_mid_nav_3');
					sticky5.removeClass('fixed_mid_nav_5');
				} 
			});
		});
	</script>
	<style>
		.fixed_mid_nav {
		    position: fixed;
		    width: 100%;
		    top: 60px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_mid_nav_3 {
		    position: fixed;
		    top: 60px;
		    width: 100%;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_mid_nav_5 {
		    position: fixed;
		    top: 60px;
		    width: 100%;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		@media only screen and (max-width: 1023px) {
			.fixed_mid_nav, .fixed_mid_nav_3, .fixed_mid_nav_5 {
			    top: 27px;
			}
			.flex_menu.header1.fixed_mid_drop_nav {
			    position: fixed !important;
			    top: 115px;
			    padding-top: 0;
			}
		}
	</style>
	<?php 
	}
	if ( true == $mid_head && true == $top_head ) {
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(window).scroll(function(){

				var sticky = jQuery('header#header .aff-header-wrapper.desktop');
				var mob_sticky = jQuery('header#header .flex_menu_secondary.header1');
				var scroll = jQuery(window).scrollTop();

				if (scroll >= 100){
					sticky.addClass('fixed_mid_nav');
					mob_sticky.addClass('fixed_mid_drop_nav');
				}else{
					sticky.removeClass('fixed_mid_nav');
					mob_sticky.removeClass('fixed_mid_drop_nav');
				} 
			});
		});
	</script>
	<style>
		.fixed_mid_nav {
		    position: fixed;
		    width: 100%;
		    top: 40px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_mid_nav_3, .fixed_mid_nav_5{
			top: 40px;
		}
		@media only screen and (max-width: 1023px) {
			.flex_menu_secondary.header1.fixed_mid_drop_nav {
			    position: fixed !important;
			    top: 125px;
			    padding-top: 0;
			    width: 100%;
			}
		}
		@media only screen and (max-width: 480px) {
			.flex_menu_secondary.header1.fixed_mid_drop_nav{
				top: 112px;
			}
		}
	</style>
	<?php 
	}
	if ( true == $mid_head && false == $top_head ) {
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(window).scroll(function(){

				var sticky = jQuery('header#header .aff-header-wrapper.desktop');
				var mob_sticky = jQuery('header#header .flex_menu_secondary.header1');
				var scroll = jQuery(window).scrollTop();

				if (scroll >= 100){
					sticky.addClass('fixed_mid_nav');
					mob_sticky.addClass('fixed_mid_drop_nav');
				}else{
					sticky.removeClass('fixed_mid_nav');
					mob_sticky.removeClass('fixed_mid_drop_nav');
				} 
			});
		});
	</script>
	<style>
		.fixed_mid_nav {
		    position: fixed;
		    width: 100%;
		    top: 0px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_mid_nav_3, .fixed_mid_nav_5{
			top: 0px;
		}
		@media only screen and (max-width: 1023px) {
			.fixed_mid_nav {
			    top: 0px;
			}
			.flex_menu.header1.fixed_mid_drop_nav {
			    position: fixed !important;
			    top: 88px;
			    padding-top: 0;
			}
		}
	</style>
	<?php 
	}
	if ( true == $bot_head ) {
	?>
	<script type="text/javascript">
		jQuery(document).ready(function(){
			jQuery(window).scroll(function(){

				var sticky = jQuery('header#header .aff-header-3 .aff-header-bottom');
				var sticky_drop = jQuery('header#header .flex_menu.header3');
				var sticky5 = jQuery('header#header .aff-header-5 .aff-header-bottom');
				var sticky5_drop = jQuery('header#header .flex_menu.header5');
				var sticky1_bot = jQuery('header#header .aff-header-bottom.aff-head1-bottom');
				var sticky1_bot_drp = jQuery('.aff-sidebar-action-wrapperr.flex_menu.header1');
				
				var scroll = jQuery(window).scrollTop();

				if (scroll >= 100){
					sticky.addClass('fixed_bot_nav');
					sticky_drop.addClass('fixed_bot_nav_drp');
					sticky5.addClass('fixed_bot_nav5');
					sticky5_drop.addClass('fixed_bot_nav5_drp');
					sticky1_bot.addClass('fixed_bot_nav_1');
					sticky1_bot_drp.addClass('fixed_bot_nav_1_drp');
				}else{
					sticky.removeClass('fixed_bot_nav');
					sticky_drop.removeClass('fixed_bot_nav_drp');
					sticky5.removeClass('fixed_bot_nav5');
					sticky5_drop.removeClass('fixed_bot_nav5_drp');
					sticky1_bot.removeClass('fixed_bot_nav_1');
					sticky1_bot_drp.removeClass('fixed_bot_nav_1_drp');
					
				} 
			});
		});
	</script>
	<style>
		.fixed_bot_nav{
		    position: fixed;
		    width: 100%;
		    top: 0px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_bot_nav_1 {
		    position: fixed;
		    width: 100%;
		    top: 0px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_bot_nav5 {
		    position: fixed;
		    top: 0px;
		    width: 100%;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		
		@media only screen and (max-width: 1023px) {
			.fixed_bot_nav{
				top: 116px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header3.fixed_bot_nav_drp {
			    position: fixed !important;
			    top: 166px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
			    position: fixed !important;
			    top: 50px;
			}
			.fixed_bot_nav5 {
			    top: 0px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header5.fixed_bot_nav5_drp {
			    position: fixed !important;
			    top: 50px;
			}
		}
	</style>
	<?php 
	}

	if ( true == $bot_head && true == $mid_head && true != $top_head ) {
	?>
	<style>
		.fixed_bot_nav{
			top: 100px;
		}
		.fixed_bot_nav5 {
		    top: 92px;
		}
		.fixed_bot_nav_1 {
		    top: 85px;
		}
		.flex_menu_secondary.header1.fixed_mid_drop_nav {
		    position: fixed;
		    width: 100%;
		    top: 85px;
		    z-index: 99;
		}
		@media only screen and (max-width: 1023px) {
			.fixed_bot_nav5 {
			    top: 84px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
			    position: fixed !important;
			    top: 135px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header3.fixed_bot_nav_drp {
			    top: 139px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header5.fixed_bot_nav5_drp{
				top: 134px;
			}
		}
		@media only screen and (max-width: 480px) {
			.fixed_bot_nav_1 {
			    top: 70px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
			    top: 120px;
			}
			.flex_menu_secondary.header1.fixed_mid_drop_nav{
				top: 70px;
			}
		}
		
	</style>
	<?php
	}
	if ( true == $bot_head && true != $mid_head && true == $top_head ) {
	?>
	<style>
		.fixed_bot_nav, .fixed_bot_nav5{
			top: 60px;
		}
		.fixed_bot_nav_1 {
		    position: fixed;
		    width: 100%;
		    top: 40px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
		    position: fixed !important;
		    top: 90px;
		}
		@media only screen and (max-width: 1023px) {
			.fixed_bot_nav{
				top: 24px;
			}

			.fixed_bot_nav5 {
			    top: 24px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header3.fixed_bot_nav_drp,
			.aff-sidebar-action-wrapperr.flex_menu.header5.fixed_bot_nav5_drp {
			    position: fixed !important;
			    top: 77px;
			}
		}
	</style>
	<?php
	}
	if ( true == $bot_head && true == $mid_head && true == $top_head ) {
	?>
	<style>
		.aff-header-3 .fixed_bot_nav {
		    top: 125px;
		}
		.fixed_bot_nav {
		    top: 160px;
		}
		.fixed_mid_nav {
		    top: 24px;
		}
		.fixed_mid_nav {
		    top: 40px;
		}
		.fixed_bot_nav_1 {
		    position: fixed;
		    width: 100%;
		    top: 125px;
		    animation: smoothScroll .8s forwards;
		    z-index: 9;
		}
		.fixed_bot_nav5 {
		    top: 160px;
		}
		
		@media only screen and (max-width: 1023px) {
			.flex_menu_secondary.header1.fixed_mid_drop_nav {
			    position: fixed !important;
			    top: 108px;
			    padding-top: 0;
			    width: 100%;
			    z-index: 99;
			}
			.fixed_bot_nav_1 {
			    top: 108px;
			}
			.fixed_mid_nav {
			    top: 24px;
			}
			.fixed_bot_nav {
			    top: 124px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
			    top: 158px;
			}
			.aff-header-3 .fixed_bot_nav {
			    top: 108px;
			}
			.fixed_mid_nav_3 {
			    top: 24px;
			}
			.fixed_mid_nav_5 {
			    top: 24px;
			}
			.fixed_bot_nav5 {
			    top: 108px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header5.fixed_bot_nav5_drp {
			    top: 158px;
			}
		}
		@media only screen and (max-width: 480px) {
			.flex_menu_secondary.header1.fixed_mid_drop_nav {
				top: 97px;
			}
			.fixed_bot_nav_1 {
			    top: 97px;
			}
			.aff-sidebar-action-wrapperr.flex_menu.header1.fixed_bot_nav_1_drp {
			    top: 147px;
			}
		}
			
	</style>
	<?php
	}


}
add_action( 'wp_head', 'afftheme_fixed_header');
add_action( 'wp_head', function(){
?>
<!-- <style>
	.post.aff-thumbnail-style4 .aff-post-gallery>a:before{
        content:"";
        background-image:url(<?php //echo esc_url(home_url().'/wp-content/themes/affiliatebooster/images/default.webp'); ?>);
        position:absolute;
        height:150px;
        width:150px;
        background-size:cover;
        background-position:-78px -29px;
    }
</style> -->
<?php
});


/*
* Choose Header logo in cutsomizer
*/
function register_my_menus() {
  register_nav_menus(
    array(
      'header-menu' => __( 'Primary Menu', 'affiliatebooster'),
      'secondary-menu' => __( 'Secondary Menu', 'affiliatebooster' ),
	  'footer-menu' => __( 'Footer Menu', 'affiliatebooster' ),
	  'above-header-menu' => __( 'Above Header Menu', 'affiliatebooster' ),
     )
   );
}
add_action( 'init', 'register_my_menus' );

function custom_logo(){
						
	$custom_logo = get_theme_mod( 'site_identity_site_logo_settings', '' );
	$img_width = get_theme_mod( 'site_identity_image_width_slider_settings', '220' );

	if($custom_logo == ''){
		if ( true == get_theme_mod( 'switch_setting_for_default_logo', true ) ) {
			$custom_logo = get_template_directory_uri(). '/images/aff-booster-logo.png';
			$img_width = get_theme_mod( 'site_identity_image_width_slider_settings', '220' );
			?>
			<a href="<?php echo esc_url(home_url()); ?>"><img class="aff-logo" src="<?php echo $custom_logo; ?>" alt="<?php echo get_bloginfo( 'name' ); ?>" style="width: <?php echo $img_width.'px'; ?>;"></a>
			<?php
		}else{
			$tsum_options_title = get_theme_mod('site_identity_hide_title_settings', '');
			$tsum_options_tag = get_theme_mod('site_identity_hide_tagline_settings', '');
			if( true != $tsum_options_title ){
				if (get_theme_mod('site_identity_text_settings','') == '') {
					?>
						<a href="<?php echo esc_url( home_url( "/" ) ); ?>" class="site_title" rel="home"><?php echo bloginfo( "name" ); ?></a>
					<?php
				}else{
					?>
						<a href="<?php echo esc_url( home_url( "/" ) ); ?>" class="site_title" rel="home"><?php echo esc_html( get_theme_mod('site_identity_text_settings','') ); ?></a>
					<?php
				}
			}
			if( true != $tsum_options_tag ){
				if (get_theme_mod('site_identity_tagline_settings','') == '') {
					?>
						<p class="site-description"><?php echo get_bloginfo( 'description', 'display' ); ?></p>
					<?php
				}else{
					?>
						<p class="site-description"><?php echo esc_html( get_theme_mod('site_identity_tagline_settings','') ); ?></p>
					<?php
				}	
			}
		}
			
	}else{
		?>
		<a href="<?php echo esc_url(esc_url(home_url())); ?>"><img class="aff-logo" src="<?php echo $custom_logo; ?>" alt="<?php echo get_bloginfo( 'name' ); ?>" style="width: <?php echo $img_width.'px'; ?>;"></a>
		<?php
	}
	
}

function set_number_views()
{
	global $post;
	$post_id = $post->ID;
	$count_key = 'post_views_count';
    $count = get_post_meta($post_id, $count_key, true);
    if($count ==''){
        $count = 0;
        add_post_meta($post_id, $count_key, '0');
    }else{
		$count++;
		update_post_meta($post_id, $count_key, $count);
    }
}
add_filter('manage_posts_columns', 'posts_column_views');
add_action('manage_posts_custom_column', 'posts_custom_column_views',5,2);
function posts_column_views($defaults){
		$defaults['post_views'] = __('Views', 'affiliatebooster');
		return $defaults;
}
function posts_custom_column_views($column_name, $id){
	$column_name;
	if($column_name === 'post_views'){
			echo get_post_meta($id, 'post_views_count', true);
	}
}
// Remove comment date
function wpb_remove_comment_date($date, $d, $comment) {
    if ( !is_admin() ) {
        return;
    } else {
        return $date;
    }
}
// add_filter( 'get_comment_date', 'wpb_remove_comment_date', 10, 3);

// Remove comment time
function wpb_remove_comment_time($date, $d, $comment) {
    if ( !is_admin() ) {
            return;
    } else {
            return $date;
    }
}
// add_filter( 'get_comment_time', 'wpb_remove_comment_time', 10, 3);

//Comment move fields to bottom
function wpb_move_comment_field_to_bottom( $fields ) {
	$comment_field = $fields['comment'];
	unset( $fields['comment'] );
	unset( $fields['cookies-consent'] );
	$fields['comment'] = $comment_field;
	return $fields;
	}
add_filter( 'comment_form_fields', 'wpb_move_comment_field_to_bottom' );

//Comment form restyle
function affiliatebooster_update_comment_fields( $fields ) {

	$commenter = wp_get_current_commenter();
	$req       = get_option( 'require_name_email' );
	$label     = $req ? '*' : ' ' . __( '(optional)', 'affiliatebooster' );
	$aria_req  = $req ? "aria-required='true'" : '';

	$fields['author'] =
		'<p class="col-md-4 float-left comment-form-author">
			<input id="author" name="author" type="text" placeholder="' . esc_attr__( "Name*", "affiliatebooster" ) . '" value="' . esc_attr( $commenter['comment_author'] ) .
		'" size="30" ' . $aria_req . ' />
		</p>';

	$fields['email'] =
		'<p class="col-md-4 float-left comment-form-email">
			<input id="email" name="email" type="email" placeholder="' . esc_attr__( "Email*", "affiliatebooster" ) . '" value="' . esc_attr( $commenter['comment_author_email'] ) .
		'" size="30" ' . $aria_req . ' />
		</p>';

	$fields['url'] =
		'<p class="col-md-4 float-left comment-form-url">
			<input id="url" name="url" type="url"  placeholder="' . esc_attr__( "Website", "affiliatebooster" ) . '" value="' . esc_attr( $commenter['comment_author_url'] ) .
		'" size="30" />
			</p>';

	return $fields;
}
add_filter( 'comment_form_default_fields', 'affiliatebooster_update_comment_fields' );

function affiliatebooster_update_comment_field( $comment_field ) {

	$comment_field =
	  '<p class="col-md-12 float-left comment-form-comment">
			  <textarea required id="comment" name="comment" placeholder="' . esc_attr__( "Type here..", "affiliatebooster" ) . '" cols="45" rows="8" aria-required="true"></textarea>
		  </p>';
  
	return $comment_field;
  }
  add_filter( 'comment_form_field_comment', 'affiliatebooster_update_comment_field' );

// Breadcrumbs
function custom_breadcrumbs() {

	$breadcrumbs = '';
	//function_exists('rank_math_the_breadcrumbs')
	if (function_exists( 'rank_math_the_breadcrumbs' )){
		$breadcrumbs = rank_math_get_breadcrumbs();
	}
	if ( $breadcrumbs != '' ){ rank_math_the_breadcrumbs(); 
	}
	else{
		
		$home_text = get_theme_mod('breadcrumbs_home_text');
		if ( empty($home_text) ) {
			$home_text = 'Home';
		}
	       
	    // Settings
	    $separator          = '&nbsp; &gt; &nbsp;';
	    $breadcrums_id      = 'breadcrumbs';
	    $breadcrums_class   = 'breadcrumbs';
	    $home_title         = $home_text;
	      
	    // If you have any custom post types with custom taxonomies, put the taxonomy name below (e.g. product_cat)
	    $custom_taxonomy    = 'product_cat';
	       
	    // Get the query & post information
	    global $post,$wp_query;
	       
	    // Do not display on the homepage
	    if ( !is_front_page() ) {
	       	$bfcumb_color = get_theme_mod( 'single_post_breadcrumb_color_setting','#178133' );
	       
	        // Build the breadcrums
	        echo '<ul id="' . $breadcrums_id . '" class="' . $breadcrums_class . '">';
	           
	        // Home page
	        echo '<li class="item-home bread-link-color"><a class="bread-link bread-home" href="' . get_home_url() . '" title="' . $home_title . '">' . $home_title . '</a></li>';
	        echo '<li class="separator separator-home"> ' . $separator . ' </li>';
	           
	        if ( is_archive() && !is_tax() && !is_category() && !is_tag() ) {
	              
	            echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . post_type_archive_title($prefix, false) . '</strong></li>';
	              
	        } else if ( is_archive() && is_tax() && !is_category() && !is_tag() ) {
	              
	            // If post is a custom post type
	            $post_type = get_post_type();
	              
	            // If it is a custom post type display name and link
	            if($post_type != 'post') {
	                  
	                $post_type_object = get_post_type_object($post_type);
	                $post_type_archive = get_post_type_archive_link($post_type);
	              
	                echo '<li class="item-cat item-custom-post-type-' . $post_type . '"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></li>';
	                echo '<li class="separator"> ' . $separator . ' </li>';
	              
	            }
	              
	            $custom_tax_name = get_queried_object()->name;
	            echo '<li class="item-current item-archive"><strong class="bread-current bread-archive">' . $custom_tax_name . '</strong></li>';
	              
	        } else if ( is_single() ) {
	              
	            // If post is a custom post type
	            $post_type = get_post_type();
	              
	            // If it is a custom post type display name and link
	            if($post_type != 'post') {
	                  
	                $post_type_object = get_post_type_object($post_type);
	                $post_type_archive = get_post_type_archive_link($post_type);
	              
	                echo '<li class="item-cat item-custom-post-type-' . $post_type . '"><a class="bread-cat bread-custom-post-type-' . $post_type . '" href="' . $post_type_archive . '" title="' . $post_type_object->labels->name . '">' . $post_type_object->labels->name . '</a></li>';
	                echo '<li class="separator"> ' . $separator . ' </li>';
	              
	            }
	              
	            // Get post category info
	            $category = get_the_category();
	             
	            if(!empty($category)) {
	              
	                // Get last category post is in
	                $last_category = $category[count($category) - 1];
	                  
	                // Get parent any categories and create array
	                $get_cat_parents = rtrim(get_category_parents($last_category->term_id, true, ','),',');
	                $cat_parents = explode(',',$get_cat_parents);
	                  
	                // Loop through parent categories and store in variable $cat_display
	                $cat_display = '';
	                foreach($cat_parents as $parents) {
	                	 
	                    $cat_display .= '<li class="item-cat bread-link-color">'.$parents.'</li>';
	                    $cat_display .= '<li class="separator"> ' . $separator . ' </li>';
	                }
	             
	            }
	              
	            // If it's a custom post type within a custom taxonomy
	            $taxonomy_exists = taxonomy_exists($custom_taxonomy);
	            if(empty($last_category) && !empty($custom_taxonomy) && $taxonomy_exists) {
	                   
	                $taxonomy_terms = get_the_terms( $post->ID, $custom_taxonomy );
	                $cat_id         = $taxonomy_terms[0]->term_id;
	                $cat_nicename   = $taxonomy_terms[0]->slug;
	                $cat_link       = get_term_link($taxonomy_terms[0]->term_id, $custom_taxonomy);
	                $cat_name       = $taxonomy_terms[0]->name;
	               
	            }
	              
	            // Check if the post is in a category
	            if(!empty($last_category)) {
	                echo $cat_display;
	                echo '<li class="item-current item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';
	                  
	            // Else if post is in a custom taxonomy
	            } else if(!empty($cat_id)) {
	                  
	                echo '<li class="item-cat item-cat-' . $cat_id . ' item-cat-' . $cat_nicename . '"><a class="bread-cat bread-cat-' . $cat_id . ' bread-cat-' . $cat_nicename . '" href="' . $cat_link . '" title="' . $cat_name . '">' . $cat_name . '</a></li>';
	                echo '<li class="separator"> ' . $separator . ' </li>';
	                echo '<li class="item-current item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';
	              
	            } else {
	                  
	                echo '<li class="item-current item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';
	                  
	            }
	              
	        } else if ( is_category() ) {
	               
	            // Category page
	            echo '<li class="item-current item-cat"><strong class="bread-current bread-cat">' . single_cat_title('', false) . '</strong></li>';
	               
	        } else if ( is_page() ) {
	               
	            // Standard page
	            if( $post->post_parent ){
	                   
	                // If child page, get parents 
	                $anc = get_post_ancestors( $post->ID );
	                   
	                // Get parents in the right order
	                $anc = array_reverse($anc);
	                   
	                // Parent page loop
	                if ( !isset( $parents ) ) $parents = null;
	                foreach ( $anc as $ancestor ) {
	                    $parents .= '<li class="item-parent item-parent-' . $ancestor . '"><a class="bread-parent bread-parent-' . $ancestor . '" href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . '</a></li>';
	                    $parents .= '<li class="separator separator-' . $ancestor . '"> ' . $separator . ' </li>';
	                }
	                   
	                // Display parent pages
	                echo $parents;
	                   
	                // Current page
	                echo '<li class="item-current item-' . $post->ID . '"><strong title="' . get_the_title() . '"> ' . get_the_title() . '</strong></li>';
	                   
	            } else {
	                   
	                // Just display current page if not parents
	                echo '<li class="item-current item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '"> ' . get_the_title() . '</strong></li>';
	                   
	            }
	               
	        } else if ( is_tag() ) {
	               
	            // Tag page
	               
	            // Get tag information
	            $term_id        = get_query_var('tag_id');
	            $taxonomy       = 'post_tag';
	            $args           = 'include=' . $term_id;
	            $terms          = get_terms( $taxonomy, $args );
	            $get_term_id    = $terms[0]->term_id;
	            $get_term_slug  = $terms[0]->slug;
	            $get_term_name  = $terms[0]->name;
	               
	            // Display the tag name
	            echo '<li class="item-current item-tag-' . $get_term_id . ' item-tag-' . $get_term_slug . '"><strong class="bread-current bread-tag-' . $get_term_id . ' bread-tag-' . $get_term_slug . '">' . $get_term_name . '</strong></li>';
	           
	        } elseif ( is_day() ) {
	               
	            // Day archive
	               
	            // Year link
	            echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</a></li>';
	            echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
	               
	            // Month link
	            echo '<li class="item-month item-month-' . get_the_time('m') . '"><a class="bread-month bread-month-' . get_the_time('m') . '" href="' . get_month_link( get_the_time('Y'), get_the_time('m') ) . '" title="' . get_the_time('M') . '">' . get_the_time('M') . ' Archives</a></li>';
	            echo '<li class="separator separator-' . get_the_time('m') . '"> ' . $separator . ' </li>';
	               
	            // Day display
	            echo '<li class="item-current item-' . get_the_time('j') . '"><strong class="bread-current bread-' . get_the_time('j') . '"> ' . get_the_time('jS') . ' ' . get_the_time('M') . ' Archives</strong></li>';
	               
	        } else if ( is_month() ) {
	               
	            // Month Archive
	               
	            // Year link
	            echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link( get_the_time('Y') ) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</a></li>';
	            echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
	               
	            // Month display
	            echo '<li class="item-month item-month-' . get_the_time('m') . '"><strong class="bread-month bread-month-' . get_the_time('m') . '" title="' . get_the_time('M') . '">' . get_the_time('M') . ' Archives</strong></li>';
	               
	        } else if ( is_year() ) {
	               
	            // Display year archive
	            echo '<li class="item-current item-current-' . get_the_time('Y') . '"><strong class="bread-current bread-current-' . get_the_time('Y') . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</strong></li>';
	               
	        } else if ( is_author() ) {
	               
	            // Auhor archive
	               
	            // Get the author information
	            global $author;
	            $userdata = get_userdata( $author );
	               
	            // Display author name
	            echo '<li class="item-current item-current-' . $userdata->user_nicename . '"><strong class="bread-current bread-current-' . $userdata->user_nicename . '" title="' . $userdata->display_name . '">' . 'Author: ' . $userdata->display_name . '</strong></li>';
	           
	        } else if ( get_query_var('paged') ) {
	               
	            // Paginated archives
	            echo '<li class="item-current item-current-' . get_query_var('paged') . '"><strong class="bread-current bread-current-' . get_query_var('paged') . '" title="Page ' . get_query_var('paged') . '">'.__('Page', 'affiliatebooster') . ' ' . get_query_var('paged') . '</strong></li>';
	               
	        } else if ( is_search() ) {
	           
	            // Search results page
	            echo '<li class="item-current item-current-' . get_search_query() . '"><strong class="bread-current bread-current-' . get_search_query() . '" title="Search results for: ' . get_search_query() . '">Search results for: ' . get_search_query() . '</strong></li>';
	           
	        } elseif ( is_404() ) {
	               
	            // 404 page
	            echo '<li>' . 'Error 404' . '</li>';
	        }
	       
	        echo '</ul>';
	           
	    }
	} // else end	
       
}

/* Search Query */
if (!is_admin()) {
	function wpb_search_filter($query) {
	if ($query->is_search) {
	$query->set('post_type', 'post');
	}
	return $query;
	}
	add_filter('pre_get_posts','wpb_search_filter');
}

/* Changed sidbar widget title to h3*/
function affiliate_change_widget_title_tag( $params ) {
$params[0]['before_title'] = '<h3 class="widget-title widgettitle">' ;
$params[0]['after_title']  = '</h3>' ;
return $params;
}
add_filter( 'dynamic_sidebar_params' , 'affiliate_change_widget_title_tag' );

/* Add custom metabox in post */
add_action( 'admin_init', 'affiliatebooster_metabox_function' );
function affiliatebooster_metabox_function(){
	add_meta_box( '_mymetaboxid', 'Add Container width', 'metaboxfunction1', ['page'], 'side' );
	$layout = get_theme_mod('aff_single_layout', 'layout3');
	if($layout != 'layout3'){
		add_meta_box( '_mymetaboxlayout3id', 'Add Container width', 'metaboxfunction1', ['post'], 'side' );
	}
}

function metaboxfunction1($post){
	// Get meta box value
	$getmetaboxvalue = get_post_meta( $post->ID, '_mymetaboxname', true ) ? get_post_meta( $post->ID, '_mymetaboxname', true ) : '';
	?>
	<label>Width(<small>eg. 1350</small>) : <input type="text" name="_mymetaboxname" value="<?php echo $getmetaboxvalue; ?>"></label>
	<?php
}

// To save metabox value
add_action( 'save_post', 'affiliate_save_metabox_post' );
function affiliate_save_metabox_post($post_id){

	if ( array_key_exists('_mymetaboxname', $_POST) ) {
		update_post_meta( $post_id, '_mymetaboxname', $_POST['_mymetaboxname'] );
	}

}
add_action('wp_footer', function(){
	?>
	<script type="text/javascript">
		jQuery(window).load(function(){
			jQuery('.comment-author').attr('itemprop','author');
			jQuery('b.fn').attr('itemprop','name');
			jQuery('b.fn a').attr('itemprop','url');
			jQuery('.comment-content p').attr('itemprop','text');
		});
	</script>
	<?php
});

/* Link Style 1 */
function new_excerpt_more($more) {
global $post;
   return '<br> … <a href="'. get_permalink($post->ID) . '">' . 'Read More &raquo;' . '</a>';
}
add_filter('excerpt_more', 'new_excerpt_more');

function aff_woocommerce_support() {
	add_theme_support( 'woocommerce', array(
		'thumbnail_image_width' => 150,
		'single_image_width'    => 300,

        'product_grid'          => array(
            'default_rows'    => 3,
            'min_rows'        => 2,
            'max_rows'        => 8,
            'default_columns' => 3,
            'min_columns'     => 2,
            'max_columns'     => 5,
        ),
	) );
}
add_action( 'after_setup_theme', 'aff_woocommerce_support' );