<?php
/**
 * Options.
 */

defined( 'ABSPATH' ) || die( "Can't access directly" );

//$layout = get_theme_mod('aff_single_layout', 'layout3');
/**
 * Load metaboxes.
 */
function aff_booster_metabox_setup() {
	$layout = get_theme_mod('aff_single_layout', 'layout3');
	if ($layout != 'layout3' && !is_single() ) {
		add_action( 'add_meta_boxes', 'aff_booster_metaboxes_2' );
	}
	add_action( 'add_meta_boxes', 'aff_booster_metaboxes' );
	add_action( 'save_post', 'aff_booster_save_metadata', 10, 2 );

}
add_action( 'load-post.php', 'aff_booster_metabox_setup' );
add_action( 'load-post-new.php', 'aff_booster_metabox_setup' );

/**
 * Metaboxes.
 */
function aff_booster_metaboxes() {

	// Get public post types.
	$post_types = get_post_types( array( 'public' => true ) );

	// Remove post types from array.
	unset( $post_types['aff_booster_hooks'], $post_types['elementor_library'], $post_types['fl-builder-template'] );

	// Add options metabox.
	add_meta_box( 'aff_booster', __( 'Template Settings', 'affiliatebooster' ), 'aff_booster_options_metabox_callback', $post_types, 'side', 'default' );

	// Add sidebar metabox for pages.
	add_meta_box( 'aff_booster_sidebar', __( 'Page Sidebar', 'affiliatebooster' ), 'aff_booster_sidebar_metabox_callback_page', ['page'], 'side', 'default' );
}

/**
 * Metaboxes 2.
 */
function aff_booster_metaboxes_2() {

	// Get public post types.
	$post_types = get_post_types( array( 'public' => true ) );

	// Remove post types from array.
	unset( $post_types['aff_booster_hooks'], $post_types['elementor_library'], $post_types['fl-builder-template'] );

	// Add sidebar metabox post.
	add_meta_box( 'aff_booster_sidebar', __( 'Sidebar', 'affiliatebooster' ), 'aff_booster_sidebar_metabox_callback', ['post'], 'side', 'default' );
}

/**
 * Options metabox callback.
 *
 * @param object $post The post oject.
 */
function aff_booster_options_metabox_callback( $post ) {

	wp_nonce_field( basename( __FILE__ ), 'aff_booster_options_nonce' );

	$aff_booster_stored_meta = get_post_meta( $post->ID, 'aff_booster_options', true );
	$aff_booster_stored_meta = empty( $aff_booster_stored_meta ) ? array() : $aff_booster_stored_meta;

	if ( in_array( 'remove-title', $aff_booster_stored_meta, true ) ) {
		$remove_title = 'remove-title';
	} else {
		$remove_title = false;
	}

	if ( in_array( 'remove-featured', $aff_booster_stored_meta, true ) ) {
		$remove_featured = 'remove-featured';
	} else {
		$remove_featured = false;
	}

	if ( in_array( 'remove-header', $aff_booster_stored_meta, true ) ) {
		$remove_header = 'remove-header';
	} else {
		$remove_header = false;
	}

	if ( in_array( 'remove-footer', $aff_booster_stored_meta, true ) ) {
		$remove_footer = 'remove-footer';
	} else {
		$remove_footer = false;
	}

	if ( in_array( 'remove-breadcrums', $aff_booster_stored_meta, true ) ) {
		$remove_breadcrums = 'remove-breadcrums';
	} else {
		$remove_breadcrums = false;
	}

	if ( in_array( 'remove-postmeta', $aff_booster_stored_meta, true ) ) {
		$remove_postmeta = 'remove-postmeta';
	} else {
		$remove_postmeta = false;
	}

	if ( in_array( 'remove-disclosure', $aff_booster_stored_meta, true ) ) {
		$remove_disclosure = 'remove-disclosure';
	} else {
		$remove_disclosure = false;
	}

	?>

	<h4><?php _e( 'Disable Elements', 'affiliatebooster' ); ?></h4>

	<div>
		<input id="remove-title" type="checkbox" name="aff_booster_options[]" value="remove-title" <?php checked( $remove_title, 'remove-title' ); ?> />
		<label for="remove-title"><?php _e( 'Page Title', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-featured" type="checkbox" name="aff_booster_options[]" value="remove-featured" <?php checked( $remove_featured, 'remove-featured' ); ?> />
		<label for="remove-featured"><?php _e( 'Featured Image', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-header" type="checkbox" name="aff_booster_options[]" value="remove-header" <?php checked( $remove_header, 'remove-header' ); ?> />
		<label for="remove-header"><?php _e( 'Header', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-footer" type="checkbox" name="aff_booster_options[]" value="remove-footer" <?php checked( $remove_footer, 'remove-footer' ); ?> />
		<label for="remove-footer"><?php _e( 'Footer', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-breadcrums" type="checkbox" name="aff_booster_options[]" value="remove-breadcrums" <?php checked( $remove_breadcrums, 'remove-breadcrums' ); ?> />
		<label for="remove-breadcrums"><?php _e( 'Breadcrums', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-postmeta" type="checkbox" name="aff_booster_options[]" value="remove-postmeta" <?php checked( $remove_postmeta, 'remove-postmeta' ); ?> />
		<label for="remove-postmeta"><?php _e( 'Post Meta', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="remove-disclosure" type="checkbox" name="aff_booster_options[]" value="remove-disclosure" <?php checked( $remove_disclosure, 'remove-disclosure' ); ?> />
		<label for="remove-disclosure"><?php _e( 'Disclosure', 'affiliatebooster' ); ?></label>
	</div>

	<?php

}

/**
 * Sidebar metabox callback.
 *
 * @param object $post The post object.
 */
function aff_booster_sidebar_metabox_callback( $post ) {

	wp_nonce_field( basename( __FILE__ ), 'aff_booster_sidebar_nonce' );

	$aff_booster_sidebar_position = get_post_meta( $post->ID, 'aff_booster_sidebar_position', true );
	$aff_booster_sidebar_position = ! empty( $aff_booster_sidebar_position ) ? $aff_booster_sidebar_position : 'global';

	?>

	<div>
		<input id="sidebar-global" type="radio" name="aff_booster_sidebar_position" value="global" <?php checked( $aff_booster_sidebar_position, 'global' ); ?> />
		<label for="sidebar-global"><?php _e( 'Inherit Global Settings', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="sidebar-right" type="radio" name="aff_booster_sidebar_position" value="right-sidebar" <?php checked( $aff_booster_sidebar_position, 'right-sidebar' ); ?> />
		<label for="sidebar-right"><?php _e( 'Right Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="sidebar-left" type="radio" name="aff_booster_sidebar_position" value="left-sidebar" <?php checked( $aff_booster_sidebar_position, 'left-sidebar' ); ?> />
		<label for="sidebar-left"><?php _e( 'Left Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="no-sidebar" type="radio" name="aff_booster_sidebar_position" value="full-width" <?php checked( $aff_booster_sidebar_position, 'full-width' ); ?> />
		<label for="no-sidebar"><?php _e( 'No Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<?php

}

/**
 * Sidebar metabox callback.
 *
 * @param object $post The post object.
 */
function aff_booster_sidebar_metabox_callback_page( $post ) {

	wp_nonce_field( basename( __FILE__ ), 'aff_booster_sidebar_nonce' );

	$aff_booster_sidebar_position_page = get_post_meta( $post->ID, 'aff_booster_sidebar_position_page', true );
	$aff_booster_sidebar_position_page = ! empty( $aff_booster_sidebar_position_page ) ? $aff_booster_sidebar_position_page : 'global';

	?>

	<div>
		<input id="sidebar-global" type="radio" name="aff_booster_sidebar_position_page" value="global" <?php checked( $aff_booster_sidebar_position_page, 'global' ); ?> />
		<label for="sidebar-global"><?php _e( 'Inherit Global Settings', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="sidebar-right" type="radio" name="aff_booster_sidebar_position_page" value="right-sidebar" <?php checked( $aff_booster_sidebar_position_page, 'right-sidebar' ); ?> />
		<label for="sidebar-right"><?php _e( 'Right Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="sidebar-left" type="radio" name="aff_booster_sidebar_position_page" value="left-sidebar" <?php checked( $aff_booster_sidebar_position_page, 'left-sidebar' ); ?> />
		<label for="sidebar-left"><?php _e( 'Left Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<div>
		<input id="no-sidebar" type="radio" name="aff_booster_sidebar_position_page" value="full-width" <?php checked( $aff_booster_sidebar_position_page, 'full-width' ); ?> />
		<label for="no-sidebar"><?php _e( 'No Sidebar', 'affiliatebooster' ); ?></label>
	</div>

	<?php

}

/**
 * Save metadata.
 *
 * @param integer $post_id The post ID.
 */
function aff_booster_save_metadata( $post_id ) {

	$is_autosave            = wp_is_post_autosave( $post_id );
	$is_revision            = wp_is_post_revision( $post_id );
	$is_valid_nonce         = ( isset( $_POST['aff_booster_options_nonce'] ) && wp_verify_nonce( $_POST['aff_booster_options_nonce'], basename( __FILE__ ) ) ) ? true : false;

	// comment due to layout3 settings
	//$is_valid_sidebar_nonce = ( isset( $_POST['aff_booster_sidebar_nonce'] ) && wp_verify_nonce( $_POST['aff_booster_sidebar_nonce'], basename( __FILE__ ) ) ) ? true : false;

	// Stop here if autosave, revision or nonce is invalid.
	if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
		return;
	}

	// Stop if current user can't edit posts.
	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	// Save options metadata.
	$checked = array();

	if ( isset( $_POST['aff_booster_options'] ) ) {

		if ( in_array( 'remove-title', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-title';
		}

		if ( in_array( 'remove-featured', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-featured';
		}

		if ( in_array( 'remove-header', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-header';
		}

		if ( in_array( 'remove-footer', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-footer';
		}

		if ( in_array( 'remove-breadcrums', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-breadcrums';
		}

		if ( in_array( 'remove-postmeta', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-postmeta';
		}

		if ( in_array( 'remove-disclosure', $_POST['aff_booster_options'], true ) ) {
			$checked[] .= 'remove-disclosure';
		}
	}

	update_post_meta( $post_id, 'aff_booster_options', $checked );

	$aff_booster_sidebar_position_page = isset( $_POST['aff_booster_sidebar_position_page'] ) ? $_POST['aff_booster_sidebar_position_page'] : '';
	update_post_meta( $post_id, 'aff_booster_sidebar_position_page', $aff_booster_sidebar_position_page );

	$layout = get_theme_mod('aff_single_layout', 'layout3');
	if ( $layout != 'layout3' && !is_single() ) {
		// Save sidebar metadata.
		$aff_booster_sidebar_position = isset( $_POST['aff_booster_sidebar_position'] ) ? $_POST['aff_booster_sidebar_position'] : '';
		update_post_meta( $post_id, 'aff_booster_sidebar_position', $aff_booster_sidebar_position );
	}
	

}
