<?php 

/**

 * Popular_Posts widget class

 *

 * @since 2.8.0

 */

class Widgets_Popular_Posts extends WP_Widget {



	function __construct() {

		$widget_ops = array('classname' => 'widget_popular_entries', 'description' => __( "The most Popular posts on your site", 'affiliatebooster' ) );

		parent::__construct('Popular-posts', __('Popular  Posts', 'affiliatebooster'), $widget_ops);

		$this->alt_option_name = 'widget_popular_entries';



		add_action( 'save_post', array($this, 'flush_widget_cache') );

		add_action( 'deleted_post', array($this, 'flush_widget_cache') );

		add_action( 'switch_theme', array($this, 'flush_widget_cache') );

	}



	

	function widget($args, $instance) {

		$cache = wp_cache_get('widget_popular_posts', 'widget');



		if ( !is_array($cache) )

			$cache = array();



		if ( ! isset( $args['widget_id'] ) )

			$args['widget_id'] = $this->id;



		if ( isset( $cache[ $args['widget_id'] ] ) ) {

			echo $cache[ $args['widget_id'] ];

			return;

		}



		ob_start();

		extract($args);



		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Popular Posts', 'affiliatebooster' );

		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;

		$orderby = ( ! empty( $instance['order_by'] ) ) ? $instance['order_by'] : 'ASC';

		if ( ! $number )

			$number = 10;

		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$remove_image = isset( $instance['remove_image'] ) ? $instance['remove_image'] : false;

		$order_by = $instance['order_by'];

		if( $order_by == 'comment_count'){ 

			$args = array('orderby' => 'comment_count', 'posts_per_page'=> $number); 

		}

		else{ $args = array(

			'posts_per_page' => $number,

			'meta_key' => $order_by,

			'orderby' => 'meta_value_num',

		); 

	}

	$r = new WP_Query( $args );



	if ($r->have_posts()) :?>

		<?php echo $before_widget; ?>

		<div class="aff-widget-title"><?php if ( $title ) echo $before_title . $title . $after_title; ?></div>

		<ul>

			<?php while ( $r->have_posts() ) : $r->the_post(); ?>

				<div class="post aff-thumbnail-style4">
					<?php if( !$remove_image ) : ?>  

						<figure class="aff-post-gallery"> 

							<a href="<?php esc_url(the_permalink()); ?>">

								<?php the_post_thumbnail('full'); ?>

							</a>

						</figure>
					<?php endif; ?>

					<div class="aff-thumbnail-style4-inner">

						<div class="aff-post-title">

							<h6><a href="<?php esc_url(the_permalink()); ?>">

								<span><?php esc_html(the_title()); ?></span>

							</a>

						</h6>

					</div>

					<?php if ( $show_date ) : ?>

						<aside class="aff-post-bottom">

							<ul>

								<li class="post-date"><?php echo get_the_date(); ?></li>

							</ul>

						</aside>

					<?php endif; ?>

				</div>

			</div>

		<?php endwhile; ?>

	</ul>

	<?php echo $after_widget; ?>

	<?php

        // Reset the global $the_post as this query will have stomped on it

	wp_reset_postdata();



endif;



        //$cache[$args['widget_id']] = ob_get_flush();

wp_cache_set('widget_popular_posts', $cache, 'widget');

}



function update( $new_instance, $old_instance ) {

	$instance = $old_instance;

	$instance['title'] = strip_tags($new_instance['title']);

	$instance['number'] = (int) $new_instance['number'];

	$instance['show_date'] = (bool) $new_instance['show_date'];

	$instance['remove_image'] = (bool) $new_instance['remove_image'];

	$instance['order_by'] = ( ! empty( $new_instance['order_by'] ) ) ? $new_instance['order_by'] : 'ASC';

	$this->flush_widget_cache();



	$alloptions = wp_cache_get( 'alloptions', 'options' );

	if ( isset($alloptions['widget_popular_entries']) )

		delete_option('widget_popular_entries');



	return $instance;

}



function flush_widget_cache() {

	wp_cache_delete('widget_popular_posts', 'widget');

}



function form( $instance ) {

	$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';

	$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;

	$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;

	$remove_image = isset( $instance['remove_image'] ) ? (bool) $instance['remove_image'] : false;

	$order_by = ( ! empty($instance['order_by']) ) ? $instance['order_by'] : 'ASC';

	?>

	<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'affiliatebooster' ); ?></label>

		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>



		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'affiliatebooster' ); ?></label>

			<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>



			<!-- Order by -->

			<p>

				<label for="<?php echo $this->get_field_id('order_by'); ?>"><?php _e('Sort posts by', 'affiliatebooster'); ?>:</label><br />

				<select id="<?php echo $this->get_field_id('order_by'); ?>" name="<?php echo $this->get_field_name('order_by'); ?>" class="widefat">

					<option value="comment_count" <?php if ( 'comment_count' == $order_by ) echo 'selected="selected"'; ?>><?php _e('Comments', 'affiliatebooster'); ?></option>

					<option value="post_views_count" <?php if ('post_views_count' == $order_by ) echo 'selected="selected"'; ?>><?php _e('Total views', 'affiliatebooster'); ?></option>

					<option value="avg" <?php if ('avg' == $order_by ) echo 'selected="selected"'; ?>><?php _e('Avg. daily views', 'affiliatebooster'); ?></option>

				</select>

			</p>



			<p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />

				<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display Post Date', 'affiliatebooster' ); ?></label></p>

				<p><input class="checkbox" type="checkbox" <?php checked( $remove_image ); ?> id="<?php echo $this->get_field_id( 'remove_image' ); ?>" name="<?php echo $this->get_field_name( 'remove_image' ); ?>" />

					<label for="<?php echo $this->get_field_id( 'remove_image' ); ?>"><?php _e( 'Remove Featured Image', 'affiliatebooster' ); ?></label></p>

					<?php

				}

			}

			function wpse97413_register_custom_widgets() {

				register_widget( 'Widgets_Popular_Posts' );

			}

			add_action( 'widgets_init', 'wpse97413_register_custom_widgets' );





/**

 * Extend Recent Posts Widget 

 *

 * Adds different formatting to the default WordPress Recent Posts Widget

 */



Class My_Recent_Posts_Widget extends WP_Widget_Recent_Posts {



	function widget($args, $instance) {



		if ( ! isset( $args['widget_id'] ) ) {

			$args['widget_id'] = $this->id;

		}



		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Recent Posts', 'affiliatebooster' );



		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */

		$title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

		$remove_image = isset( $instance['remove_image'] ) ? $instance['remove_image'] : false;

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;

		if ( ! $number )

			$number = 5;

		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;



        /**

         * Filter the arguments for the Recent Posts widget.

         *

         * @since 3.4.0

         *

         * @see WP_Query::get_posts()

         *

         * @param array $args An array of arguments used to retrieve the recent posts.

         */

        $r = new WP_Query( apply_filters( 'widget_posts_args', array(

        	'posts_per_page'      => $number,

        	'no_found_rows'       => true,

        	'post_status'         => 'publish',

        	'ignore_sticky_posts' => true

        ) ) );



        if ($r->have_posts()) :

        	?>

        	<?php echo $args['before_widget']; ?>

        	<?php if ( $title ) {

        		echo '<div class="aff-widget-title">'.$args['before_title'] . $title . $args['after_title'].'</div>';

        	} ?>

        	<ul>

        		<?php while ( $r->have_posts() ) : $r->the_post(); ?>

        			<div class="post aff-thumbnail-style4 widget_recent_post">
        				<?php if( !$remove_image ) : ?>  
        					<figure class="aff-post-gallery"> 

        						<a href="<?php esc_url(the_permalink()); ?>">

        							<?php the_post_thumbnail('full'); ?>

        						</a>

        					</figure>
        				<?php endif; ?>

        				<div class="aff-thumbnail-style4-inner">

        					<div class="aff-post-title">

        						<h6><a href="<?php esc_url(the_permalink()); ?>">

        							<span><?php esc_html(the_title()); ?></span>

        						</a>

        					</h6>

        				</div>

        				<?php if ( $show_date ) : ?>

        					<aside class="aff-post-bottom">

        						<ul>

        							<li class="post-date"><?php echo get_the_date(); ?></li>

        						</ul>

        					</aside>

        				<?php endif; ?>

        			</div>

        		</div>

        	<?php endwhile; ?>

        </ul>

        <?php echo $args['after_widget']; ?>

        <?php

        // Reset the global $the_post as this query will have stomped on it

        wp_reset_postdata();



    endif;

}


public function update( $new_instance, $old_instance ) {
	$instance              = $old_instance;
	$instance['title']     = sanitize_text_field( $new_instance['title'] );
	$instance['number']    = (int) $new_instance['number'];
	$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
	$instance['remove_image'] = (bool) $new_instance['remove_image'];
	return $instance;
}

public function form( $instance ) {
	$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
	$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
	$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
	$remove_image = isset( $instance['remove_image'] ) ? (bool) $instance['remove_image'] : false;
	?>
	<p>
		<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'affiliatebooster' ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
	</p>

	<p>
		<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'affiliatebooster' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" />
	</p>

	<p>
		<input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', 'affiliatebooster' ); ?></label>
	</p>

	<p><input class="checkbox" type="checkbox" <?php checked( $remove_image ); ?> id="<?php echo $this->get_field_id( 'remove_image' ); ?>" name="<?php echo $this->get_field_name( 'remove_image' ); ?>" />

		<label for="<?php echo $this->get_field_id( 'remove_image' ); ?>"><?php _e( 'Remove Featured Image', 'affiliatebooster' ); ?></label></p>
		<?php
	}

}

function my_recent_widget_registration() {

	unregister_widget('WP_Widget_Recent_Posts');

	register_widget('My_Recent_Posts_Widget');

}

add_action('widgets_init', 'my_recent_widget_registration');