<?php 

/**
 * Recent_Posts widget class
 *
 * @since 2.8.0
 */
class Widgets_Popular_Posts extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_popular_entries', 'description' => __( "The most Popluar posts on your site", 'affiliatebooster') );
        parent::__construct('popluar-posts', __('Popluar Posts', 'affiliatebooster'), $widget_ops);
        $this->alt_option_name = 'widget_popular_entries';

        add_action( 'save_post', array($this, 'flush_widget_cache') );
        add_action( 'deleted_post', array($this, 'flush_widget_cache') );
        add_action( 'switch_theme', array($this, 'flush_widget_cache') );
    }

	
    function widget($args, $instance) {
        $cache = wp_cache_get('widget_popular_posts', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo $cache[ $args['widget_id'] ];
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : __( 'Popluar Posts', 'affiliatebooster');
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;
		$order_by = $instance['order_by'];
		if( $order_by == 'comment_count'){ 
		$args = array('orderby' => 'comment_count', 'posts_per_page'=> $number); 
		}
		else{ $args = array(
			'posts_per_page' => $number,
			'meta_key' => $order_by,
			'orderby' => 'meta_value_num',
			); 
		}
        $r = new WP_Query( $args );
		
        if ($r->have_posts()) :
?>
        <?php echo $before_widget; ?>
        <?php if ( $title ) echo $before_title . $title . $after_title; ?>
        <ul>
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
			<li>
                <a href="<?php esc_url(the_permalink()); ?>">
                    <?php the_post_thumbnail('aff-booster-recent-thumbnails'); ?>
                </a>
                <h4>
                   <a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a>
                </h4>
				 <?php if ( $show_date ) : ?>
					<span class="post-date"><?php echo get_the_date(); ?></span>
				<?php endif; ?>
            </li>
        <?php endwhile; ?>
        </ul>
        <?php echo $after_widget; ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('widget_popular_posts', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];
		$instance['order_by'] = $new_instance['order_by'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_popular_entries']) )
            delete_option('widget_popular_entries');

        return $instance;
    }

    function flush_widget_cache() {
        wp_cache_delete('widget_popular_posts', 'widget');
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
		$order_by = $instance['order_by'];
?>
        <p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', 'affiliatebooster' ); ?></label>
        <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

        <p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'affiliatebooster' ); ?></label>
        <input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

		<!-- Order by -->
		<p>
		<label for="<?php echo $this->get_field_id('order_by'); ?>"><?php _e('Sort posts by', 'affiliatebooster'); ?>:</label><br />
		<select id="<?php echo $this->get_field_id('order_by'); ?>" name="<?php echo $this->get_field_name('order_by'); ?>" class="widefat">
			<option value="comment_count" <?php if ('comment_count' == $instance['order_by'] ) echo 'selected="selected"'; ?>><?php _e('Comments', 'affiliatebooster'); ?></option>
			<option value="post_views_count" <?php if ('post_views_count' == $instance['order_by'] ) echo 'selected="selected"'; ?>><?php _e('Total views', 'affiliatebooster'); ?></option>
			<option value="avg" <?php if ('avg' == $instance['order_by'] ) echo 'selected="selected"'; ?>><?php _e('Avg. daily views', 'affiliatebooster'); ?></option>
		</select>
		</p>
	
        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
        <label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display Post Date', 'affiliatebooster' ); ?></label></p>
<?php
    }
}
function wpse97413_register_custom_widgets() {
    register_widget( 'Widgets_Popular_Posts' );
}
add_action( 'widgets_init', 'wpse97413_register_custom_widgets' );